@@ -18,34 +18,48 @@
 
 #import "CelestiaController.h"
 #include "celestiacore.h"
+#include "render.h"
 #include "qtcapture.h"
 #import <Carbon/Carbon.h>
 
-class MacSettingsWatcher : public CelestiaWatcher
+class MacSettingsWatcher : public CelestiaWatcher, public RendererWatcher
 {
 private:
     CelestiaSettings *settings;
+    CelestiaCore *appCore;
 
 public:
     MacSettingsWatcher(CelestiaAppCore *_appCore,
                        CelestiaSettings* _settings) :
-        CelestiaWatcher(*[_appCore appCore]), settings(_settings)
-    {};
+        CelestiaWatcher(*[_appCore appCore]), settings(_settings), appCore([_appCore appCore])
+    {
+        appCore->getRenderer()->addWatcher(this);
+    };
+    
+    virtual ~MacSettingsWatcher()
+    {
+        appCore->getRenderer()->removeWatcher(this);
+    };
 
     void notifyChange(CelestiaCore *, int flags)
     {
         if ( 0 != (flags & (
-              CelestiaCore::LabelFlagsChanged
-            | CelestiaCore::RenderFlagsChanged
-            | CelestiaCore::VerbosityLevelChanged
+//              CelestiaCore::LabelFlagsChanged
+//            | CelestiaCore::RenderFlagsChanged
+            CelestiaCore::VerbosityLevelChanged
             | CelestiaCore::TimeZoneChanged
-            | CelestiaCore::AmbientLightChanged
+//            | CelestiaCore::AmbientLightChanged
             | CelestiaCore::FaintestChanged
             )) )
         {
             [settings validateItems];
         }
     };
+
+    virtual void notifyRenderSettingsChanged(const Renderer *renderer)
+    {
+        [settings validateItems];
+    };
 };
 
 class MacOSXAlerter : public CelestiaCore::Alerter
@@ -333,9 +347,10 @@ CelestiaCore *appCore;
     NSUserDefaults *prefs = [NSUserDefaults standardUserDefaults];
     NSString *confFileSetting;
     std::string confFile;
+    NSArray *existingResourceDirsSetting;
     NSArray *extrasDirsSetting;
     std::vector<std::string> extrasDirs;
-    NSString *extrasDir;
+    NSString *extrasDir = nil;
     MacOSXSplashProgressNotifier progressNotifier;
 
     if ((confFileSetting = [prefs stringForKey:@"conf"]))
@@ -343,6 +358,42 @@ CelestiaCore *appCore;
         confFile = [confFileSetting stdString];
     }
 
+    if ((existingResourceDirsSetting = [prefs stringArrayForKey:@"existingResourceDirs"]))
+    {
+        NSFileManager *fm = [NSFileManager defaultManager];
+        BOOL isFolder = NO;
+        NSEnumerator *resouceDirEnum = [existingResourceDirsSetting objectEnumerator];
+        NSString *resourceDir = nil;
+        NSString *existingConfFile = nil;
+        while ((resourceDir = [resouceDirEnum nextObject]))
+        {
+            existingConfFile = [resourceDir stringByAppendingPathComponent:@"celestia.cfg"];
+            CelestiaConfig *config = ReadCelestiaConfig([existingConfFile stdString], NULL);
+            if (config)
+            {
+                for (vector<string>::const_iterator iter = config->extrasDirs.begin();
+                     iter != config->extrasDirs.end(); iter++)
+                {
+                    if (*iter != "")
+                    {
+                        extrasDir = [NSString stringWithStdString: (*iter)];
+                        if (([fm fileExistsAtPath: extrasDir = [extrasDir stringByStandardizingPath] isDirectory: &isFolder] && isFolder) ||
+                            [fm fileExistsAtPath: extrasDir = [resourceDir stringByAppendingPathComponent:extrasDir] isDirectory: &isFolder] && isFolder)
+                        {
+                            extrasDirs.push_back([extrasDir stdString]);
+                        }
+                    }
+                }
+                delete config;
+            }
+            else
+            {
+                if ([fm fileExistsAtPath: extrasDir = [resourceDir stringByAppendingPathComponent: @"extras"] isDirectory: &isFolder] && isFolder)
+                    extrasDirs.push_back([extrasDir stdString]);
+            }
+
+        }
+    }
     if ((extrasDirsSetting = [prefs stringArrayForKey:@"extrasDirs"]))
     {
         NSEnumerator *iter = [extrasDirsSetting objectEnumerator];
@@ -353,7 +404,7 @@ CelestiaCore *appCore;
     appCore->setAlerter(new MacOSXAlerter());
     appCore->setCursorHandler(new MacOSXCursorHandler());
     result = appCore->initSimulation(!confFile.empty() ? &confFile : nil,
-                                     extrasDirsSetting ? &extrasDirs : nil,
+                                     &extrasDirs,
                                      &progressNotifier);
     if (result)
     {
@@ -542,7 +593,10 @@ CelestiaCore *appCore;
 
 -(NSString *) currentURL
 {
-    Url currentUrl = Url(appCore, Url::Absolute);
+    CelestiaState appState;
+    appState.captureState(appCore);
+    Url currentUrl(appState, Url::CurrentVersion);
+    
     NSString *url = [ NSString stringWithStdString: currentUrl.getAsString() ];
     return url;
 }
@@ -595,10 +649,13 @@ CelestiaCore *appCore;
 
     case Selection::Type_Star:
         {
-            char name[32];
-            sprintf(name, "HIP%d", sel.star()->getCatalogNumber() & ~0xf0000000);
-
-            url = string("http://simbad.u-strasbg.fr/sim-id.pl?protocol=html&Ident=") + name;
+            url = sel.star()->getInfoURL();
+            if (url.empty())
+            {
+                char name[32];
+                sprintf(name, "HIP%d", sel.star()->getCatalogNumber() & ~0xf0000000);                
+                url = string("http://simbad.u-strasbg.fr/sim-id.pl?protocol=html&Ident=") + name;
+            }
         }
         break;
 
