@@ -15,18 +15,15 @@
 -(NSString*)name;
 -(NSNumber*)radius;
 -(NSNumber*)mass;
--(NSNumber*)oblateness;
 -(NSNumber*)albedo;
 -(CelestiaVector*)orientation;
 -(void)setOrientation:(CelestiaVector*)q;
 -(void)setName:(NSString*)s;
--(void)setRadius:(NSNumber*)r;
 -(void)setMass:(NSNumber*)m;
--(void)setOblateness:(NSNumber*)o;
 -(void)setAlbedo:(NSNumber*)a;
--(CelestiaVector*)heliocentricPosition:(NSNumber*)n;
+-(CelestiaVector*)astrocentricPosition:(NSNumber*)n;
 -(CelestiaVector*)equatorialToBodyFixed:(NSNumber*)n;
--(CelestiaVector*)eclipticalToEquatorial:(NSNumber*)n;
--(CelestiaVector*)eclipticalToBodyFixed:(NSNumber*)n;
+-(CelestiaVector*)eclipticToEquatorial:(NSNumber*)n;
+-(CelestiaVector*)eclipticToBodyFixed:(NSNumber*)n;
 -(NSArray*)alternateSurfaceNames;
 @end
