@@ -73,8 +73,13 @@ NSString* fatalErrorMessage;
         return;
     }
     
+	BOOL nosplash = [[NSUserDefaults standardUserDefaults] boolForKey:@"nosplash"];
     startupCondition = [[NSConditionLock alloc] initWithCondition: 0];
 
+	if (!nosplash)
+	{
+		[splashWindowController showWindow];
+	}
     if (threaded)
     {
         // start initialization thread
@@ -96,49 +101,65 @@ NSString* fatalErrorMessage;
     // Change directory to resource dir so Celestia can find cfg files and textures
     NSFileManager *fileManager = [NSFileManager defaultManager]; 
     NSString* path;
+    NSMutableArray *resourceDirs = [NSMutableArray array];
     BOOL isFolder = NO;
 
-    if ( [ fileManager fileExistsAtPath: path = [[[ mainBundle bundlePath ]  stringByDeletingLastPathComponent] stringByAppendingPathComponent: CELESTIA_RESOURCES_FOLDER ] isDirectory: &isFolder ] && isFolder )
-        [fileManager changeCurrentDirectoryPath: path];
-    else
+    if ( [ fileManager fileExistsAtPath: path = [[ mainBundle resourcePath ] stringByAppendingPathComponent: CELESTIA_RESOURCES_FOLDER ] isDirectory: &isFolder ] && isFolder )
     {
-        FSRef folder;
-        CFURLRef url;
-        static short domains[] = { kUserDomain, kLocalDomain, kNetworkDomain };
-        unsigned i;
-        path = nil;
+        [resourceDirs addObject: path];
+    }
+    if ( [ fileManager fileExistsAtPath: path = [[[ mainBundle bundlePath ]  stringByDeletingLastPathComponent] stringByAppendingPathComponent: CELESTIA_RESOURCES_FOLDER ] isDirectory: &isFolder ] && isFolder )
+    {
+        [resourceDirs addObject: path];
+    }
+    FSRef folder;
+    CFURLRef url;
+    static short domains[] = { kUserDomain, kLocalDomain, kNetworkDomain };
+    unsigned i;
+    path = nil;
 
-        for (i = 0; i < (sizeof domains / sizeof(short)); ++i)
+    for (i = 0; i < (sizeof domains / sizeof(short)); ++i)
+    {
+        if (FSFindFolder(domains[i], kApplicationSupportFolderType, FALSE, &folder) == noErr)
         {
-            if (FSFindFolder(domains[i], kApplicationSupportFolderType, FALSE, &folder) == noErr)
-            {
-                url = CFURLCreateFromFSRef(nil, &folder);
-                path = [(NSURL *)url path];
-                CFRelease(url);
+            url = CFURLCreateFromFSRef(nil, &folder);
+            path = [(NSURL *)url path];
+            CFRelease(url);
 
-                if (path)
+            if (path)
+            {
+                if (![fileManager fileExistsAtPath: path = [path stringByAppendingPathComponent: CELESTIA_RESOURCES_FOLDER]] &&
+                    kUserDomain==domains[i])
                 {
-                    if ([fileManager fileExistsAtPath: path = [path stringByAppendingPathComponent: CELESTIA_RESOURCES_FOLDER] isDirectory: &isFolder] && isFolder)
+                    if ([fileManager createDirectoryAtPath:path attributes:nil])
                     {
-                        break;
+                        [fileManager createDirectoryAtPath:[path stringByAppendingPathComponent:@"extras"] attributes:nil];
+                        [fileManager createDirectoryAtPath:[path stringByAppendingPathComponent:CEL_SCRIPTS_FOLDER] attributes:nil];
                     }
                 }
-
-                path = nil;
+                if ([fileManager fileExistsAtPath:path isDirectory:&isFolder] && isFolder)
+                {
+                    [resourceDirs addObject: path];
+                }
             }
-        }
 
-        if (path == nil)
-        {
-            if (![fileManager fileExistsAtPath: path = [[ mainBundle resourcePath ] stringByAppendingPathComponent: CELESTIA_RESOURCES_FOLDER ] isDirectory: &isFolder] || !isFolder)
-            {
-                [self fatalError: NSLocalizedString(@"It appears that the \"CelestiaResources\" directory has not been properly installed in the correct location as indicated in the installation instructions. \n\nPlease correct this and try again.",@"")];
-                [self fatalError: nil];
-            }
+            path = nil;
         }
+    }
 
-        if (path)
-            [fileManager changeCurrentDirectoryPath: path];
+    if ([resourceDirs count] > 0)
+    {
+        [fileManager changeCurrentDirectoryPath: [resourceDirs objectAtIndex: 0]];
+        [resourceDirs removeObjectAtIndex: 0];
+        if ([resourceDirs count] > 0) {
+            NSUserDefaults *prefs = [NSUserDefaults standardUserDefaults];
+            [prefs registerDefaults:[NSDictionary dictionaryWithObject:[NSArray arrayWithObject:[resourceDirs objectAtIndex:0]] forKey:@"existingResourceDirs"]];
+        }
+    }
+    else 
+    {
+        [self fatalError: NSLocalizedString(@"It appears that the \"CelestiaResources\" directory has not been properly installed in the correct location as indicated in the installation instructions. \n\nPlease correct this and try again.",@"")];
+        [self fatalError: nil];
     }
 }
 
@@ -146,7 +167,6 @@ NSString* fatalErrorMessage;
 {
     NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
 
-    if (!threaded) [splashWindowController showWindow];
     [[glView openGLContext] makeCurrentContext];
 #ifdef DEBUG
     NSDate *t = [NSDate date];
@@ -210,7 +230,6 @@ NSString* fatalErrorMessage;
             return;
         // beginModalSession also displays the window, but the centering
         // is wrong so do the display and centering beforehand
-        [splashWindowController showWindow];
         session = [NSApp beginModalSessionForWindow: [splashWindowController window]];
         for (;;) 
         {
@@ -223,10 +242,10 @@ NSString* fatalErrorMessage;
         }
         [NSApp endModalSession:session];
     }
+    [splashWindowController close];
     // check for fatal error in loading thread
     [self fatalError: nil];
     // complete startup
-    [splashWindowController close];
     [self finishInitialization];
 }
 
@@ -280,7 +299,7 @@ NSString* fatalErrorMessage;
     NSString *VP_PROBLEM_EXT  = @"GL_ARB_vertex_program";
     NSString *VP_PATCH_SCRIPT = @"vp_patch.sh";
     NSString *VP_PATCH_SHELL  = @"/bin/zsh";
-    NSString *CELESTIA_CFG    = @"celestia.cfg";
+    NSString *CELESTIA_CFG    = @"~/.celestia.cfg";
 
     const char *VP_PROBLEM_RENDERERS[] = { "ATI Radeon 9200" };
     const char *glRenderer = (const char *) glGetString(GL_RENDERER);
@@ -308,12 +327,11 @@ NSString* fatalErrorMessage;
                             nil) == NSAlertDefaultReturn)
         {
             // Install it
-            NSFileManager *fm = [NSFileManager defaultManager];
-            NSString *cfgPath = [[fm currentDirectoryPath] stringByAppendingPathComponent: CELESTIA_CFG];
+            NSString *cfgPath = [CELESTIA_CFG stringByStandardizingPath];
             NSString *toolPath = [[NSBundle mainBundle] pathForResource: VP_PATCH_SCRIPT ofType: @""];
             BOOL patchInstalled = NO;
 
-            if ([fm isWritableFileAtPath: cfgPath] && toolPath)
+            if (toolPath)
             {
                 NSArray *taskArgs = [NSArray arrayWithObjects:
                     toolPath, cfgPath, nil];
@@ -336,7 +354,7 @@ NSString* fatalErrorMessage;
             }
             else
             {
-                [[CelestiaController shared] fatalError: NSLocalizedString(@"There was a problem installing the workaround. You may be running from a disk image, which is write-protected. Please try copying the CelestiaResources folder to your home directory as described in the README. You can also attempt to perform the workaround manually by following the instructions in the README.",nil)];
+                [[CelestiaController shared] fatalError: NSLocalizedString(@"There was a problem installing the workaround. You can attempt to perform the workaround manually by following the instructions in the README.",nil)];
                 [[CelestiaController shared] fatalError: nil];
             }
         }
@@ -359,13 +377,14 @@ NSString* fatalErrorMessage;
         [ appCore setStartURL: pendingUrl ];
     }
 
+    // Settings used to be loaded after starting simulation due to
+    // timezone setting requiring simulation time, but this dependency
+    // has been removed. In fact timezone needs to be set in order to
+    // correctly set the simulation time so settings loaded before starting.
+    [settings loadUserDefaults];
+
     [appCore start:[NSDate date]];
 
-    // load settings
-    // Delay applying settings until after setting simulation time
-    // This allows the timezone to be set correctly
-    [settings loadUserDefaults];
-    
     ready = YES;
     timer = [[NSTimer timerWithTimeInterval: 0.01 target: self selector:@selector(timeDisplay) userInfo:nil repeats:YES] retain];
     [[NSRunLoop currentRunLoop] addTimer:timer forMode:NSDefaultRunLoopMode];
@@ -493,6 +512,13 @@ NSString* fatalErrorMessage;
     isDirty = NO;
 }
 
+// Catch key events even when gl window is not key
+-(void)delegateKeyDown:(NSEvent *)theEvent
+{
+    if (ready)
+        [glView keyDown: theEvent];
+}
+
 // Held Key Simulation Methods ----------------------------------------------------------
 
 -(void) keyPress:(int) code hold: (int) time
