@@ -3,7 +3,7 @@
 //  celestia
 //
 //  Created by Hank Ramsey on Fri Oct 29 2004.
-//  Copyright (C) 2007, Celestia Development Team
+//  Copyright (C) 2001-9, the Celestia Development Team
 //
 
 #import "CelestiaSettings.h"
@@ -90,6 +90,8 @@ static NSMutableDictionary* tagMap;
         TAGDEF(400,@"showStars")
         TAGDEF(401,@"showPlanets")
         TAGDEF(402,@"showGalaxies")
+        TAGDEF(430,@"showGlobulars")
+        TAGDEF(417,@"showNebulae")
         TAGDEF(403,@"showDiagrams")
         TAGDEF(413,@"showBoundaries")
         TAGDEF(404,@"showCloudMaps")
@@ -98,8 +100,6 @@ static NSMutableDictionary* tagMap;
         TAGDEF(415,@"showCometTails")
         TAGDEF(416,@"showMarkers")
         TAGDEF(405,@"showOrbits")
-        TAGDEF(417,@"showNebulae")
-        TAGDEF(418,@"showOpenClusters")
 //	TAGDEF(999,@"showPartialTrajectories")
         TAGDEF(409,@"showSmoothLines")
         TAGDEF(410,@"showEclipseShadows")
@@ -108,12 +108,16 @@ static NSMutableDictionary* tagMap;
 //        TAGDEF(411,@"showStarsAsPoints")
         TAGDEF(414,@"showAutoMag")
         TAGDEF(406,@"showCelestialSphere")
+        TAGDEF(420,@"showEclipticGrid")
+        TAGDEF(421,@"showHorizonGrid")
+        TAGDEF(422,@"showGalacticGrid")
         // object labels
         TAGDEF(500,@"showStarLabels")
         TAGDEF(501,@"showPlanetLabels")
         TAGDEF(502,@"showMoonLabels")
         TAGDEF(503,@"showConstellationLabels")
         TAGDEF(504,@"showGalaxyLabels")
+        TAGDEF(514,@"showGlobularLabels")
         TAGDEF(505,@"showAsteroidLabels")
         TAGDEF(506,@"showSpacecraftLabels")
         TAGDEF(507,@"showLocationLabels")
@@ -121,6 +125,8 @@ static NSMutableDictionary* tagMap;
         TAGDEF(509,@"showNebulaLabels")
         TAGDEF(510,@"showOpenClusterLabels")
         TAGDEF(511,@"showLatinConstellationLabels")
+        TAGDEF(512,@"showDwarfPlanetLabels")
+        TAGDEF(513,@"showMinorMoonLabels")
         // popups
         TAGDEF(600,@"altSurface")
         TAGDEF(610,@"hudDetail")
@@ -137,6 +143,8 @@ static NSMutableDictionary* tagMap;
         TAGDEF(704,@"showSpacecraftOrbits")
         TAGDEF(703,@"showCometOrbits")
         TAGDEF(705,@"showStellarOrbits")
+        TAGDEF(706,@"showDwarfPlanetOrbits")
+        TAGDEF(707,@"showMinorMoonOrbits")
         // feature labels
         TAGDEF(903,@"minimumFeatureSize")
         TAGDEF(800,@"showCityLabels")
@@ -167,6 +175,7 @@ static NSMutableDictionary* tagMap;
         TAGDEF(826,@"showLineaLabels")
         TAGDEF(827,@"showFluctusLabels")
         TAGDEF(828,@"showFarrumLabels")
+        TAGDEF(829,@"showEruptiveCenterLabels")
         TAGDEF(831,@"showOtherLabels")
         // stars
 //        TAGDEF(999,@"distanceLimit")
@@ -179,15 +188,15 @@ static NSMutableDictionary* tagMap;
         nil];
     keyArray = [[tagDict allValues] retain];
 
-#if REFMARKS
     NSDictionary *volatileTagDict = [NSDictionary dictionaryWithObjectsAndKeys:
         TAGDEF(1000,@"showBodyAxes")
         TAGDEF(1001,@"showFrameAxes")
         TAGDEF(1002,@"showSunDirection")
         TAGDEF(1003,@"showVelocityVector")
+        TAGDEF(1004,@"showPlanetographicGrid")
+        TAGDEF(1005,@"showTerminator")
         nil];
     [tagDict addEntriesFromDictionary: volatileTagDict];
-#endif
 
     return self;
 }
@@ -408,6 +417,9 @@ static NSMutableDictionary* tagMap;
 RENDERMETHODS(Stars)
 RENDERMETHODS(Planets)
 RENDERMETHODS(Galaxies)
+RENDERMETHODS(Globulars)
+RENDERMETHODS(Nebulae)
+RENDERMETHODS(OpenClusters)
 RENDERMETHODS(Diagrams)
 RENDERMETHODS(Boundaries)
 RENDERMETHODS(CloudMaps)
@@ -423,8 +435,9 @@ RENDERMETHODS(RingShadows)
 RENDERMETHODS(CloudShadows)
 RENDERMETHODS(AutoMag)
 RENDERMETHODS(CelestialSphere)
-RENDERMETHODS(Nebulae)
-RENDERMETHODS(OpenClusters)
+RENDERMETHODS(EclipticGrid)
+RENDERMETHODS(HorizonGrid)
+RENDERMETHODS(GalacticGrid)
 
 // Label Settings
 
@@ -435,12 +448,15 @@ LABELMETHODS(Planet)
 LABELMETHODS(Moon)
 LABELMETHODS(Constellation)
 LABELMETHODS(Galaxy)
+LABELMETHODS(Globular)
+LABELMETHODS(Nebula)
+LABELMETHODS(OpenCluster)
 LABELMETHODS(Asteroid)
 LABELMETHODS(Spacecraft)
 LABELMETHODS(Location)
 LABELMETHODS(Comet)
-LABELMETHODS(Nebula)
-LABELMETHODS(OpenCluster)
+LABELMETHODS(DwarfPlanet)
+LABELMETHODS(MinorMoon)
 
 -(BOOL) showLatinConstellationLabels {
     return (appCore->getRenderer()->getLabelMode() & Renderer::I18nConstellationLabels) == 0;
@@ -459,6 +475,8 @@ ORBITMETHODS(Asteroid)
 ORBITMETHODS(Spacecraft)
 ORBITMETHODS(Comet)
 ORBITMETHODS(Stellar)
+ORBITMETHODS(DwarfPlanet)
+ORBITMETHODS(MinorMoon)
 
 
 -(float) minimumOrbitSize { return appCore->getRenderer()->getMinimumOrbitSize(); }
@@ -496,21 +514,74 @@ FEATUREMETHODS(Planitia)
 FEATUREMETHODS(Linea)
 FEATUREMETHODS(Fluctus)
 FEATUREMETHODS(Farrum)
+FEATUREMETHODS(EruptiveCenter)
 FEATUREMETHODS(Other)
 
 -(float) minimumFeatureSize { return appCore->getRenderer()->getMinimumFeatureSize(); }
 -(void)  setMinimumFeatureSize: (float) value { appCore->getRenderer()->setMinimumFeatureSize(value); }
 
-#if REFMARKS
 // Refmark Settings
 
-#define REFMARKMETHODS(flag)  -(BOOL) show##flag { return (appCore->getSimulation()->getSelection().body()->getVisibleReferenceMarks()&Body::flag) != 0; } -(void) setShow##flag: (BOOL) value  { appCore->getSimulation()->getSelection().body()->setVisibleReferenceMarks([self setValue: value forBit: Body::flag inSet: appCore->getSimulation()->getSelection().body()->getVisibleReferenceMarks()]); } 
+-(BOOL) showBodyAxes
+{
+    return appCore->referenceMarkEnabled("body axes");
+}
+
+-(void) setShowBodyAxes: (BOOL) value
+{
+    appCore->toggleReferenceMark("body axes");
+}
+
+-(BOOL) showFrameAxes
+{
+    return appCore->referenceMarkEnabled("frame axes");
+}
+
+-(void) setShowFrameAxes: (BOOL) value
+{
+    appCore->toggleReferenceMark("frame axes");
+}
+
+-(BOOL) showSunDirection
+{
+    return appCore->referenceMarkEnabled("sun direction");
+}
+
+-(void) setShowSunDirection: (BOOL) value
+{
+    appCore->toggleReferenceMark("sun direction");
+}
+
+-(BOOL) showVelocityVector
+{
+    return appCore->referenceMarkEnabled("velocity vector");
+}
+
+-(void) setShowVelocityVector: (BOOL) value
+{
+    appCore->toggleReferenceMark("velocity vector");
+}
+
+-(BOOL) showPlanetographicGrid
+{
+    return appCore->referenceMarkEnabled("planetographic grid");
+}
+
+-(void) setShowPlanetographicGrid: (BOOL) value
+{
+    appCore->toggleReferenceMark("planetographic grid");
+}
+
+-(BOOL) showTerminator
+{
+    return appCore->referenceMarkEnabled("terminator");
+}
+
+-(void) setShowTerminator: (BOOL) value
+{
+    appCore->toggleReferenceMark("terminator");
+}
 
-REFMARKMETHODS(BodyAxes)
-REFMARKMETHODS(FrameAxes)
-REFMARKMETHODS(SunDirection)
-REFMARKMETHODS(VelocityVector)
-#endif
 
 // Lighting Settings
 
@@ -566,20 +637,11 @@ REFMARKMETHODS(VelocityVector)
 
 // Time settings
 
+// Timezone values are inverted to maintain backward compatibility
 -(int)  timeZone { return appCore->getTimeZoneBias()==0 ? 1 : 0; }
 -(void) setTimeZone: (int) value
 {
-    NSTimeZone *tz;
-    NSDate *date = [NSDate dateWithJulian: [NSNumber numberWithDouble: [self time]]];
-    if (0 == value)
-    {
-        tz = [NSTimeZone defaultTimeZone];
-    }
-    else
-    {
-        tz = [NSTimeZone timeZoneWithAbbreviation: @"GMT"];
-    }
-    [[CelestiaAppCore sharedAppCore] setTimeZone: tz withDate: date];
+    appCore->setTimeZoneBias(0==value ? 1 : 0);
 }
 
 -(int)  dateFormat { return appCore->getDateFormat(); }
