@@ -36,15 +36,17 @@ my $resource;
 close RES;
 
 # LangID and code page
-# http://msdn.microsoft.com/library/default.asp?url=/library/en-us/intl/nls_238z.asp
+# http://msdn.microsoft.com/en-us/library/dd318693
 my %lang = (
 ar => [ '401', 1256 ],
+be => [ '423', 1251 ],
 bg => [ '402', 1251 ],
 de => [ '407', 1252 ],
 el => [ '408', 1253 ],
 en => [ '409', 1252 ],
 es => [ '40a', 1252 ],
 fr => [ '40c', 1252 ],
+gl => [ '456', 1252 ],
 hu => [ '40e', 1250 ],
 it => [ '410', 1252 ],
 ja => [ '411',  932 ],
@@ -52,14 +54,18 @@ ko => [ '412',  949 ],
 lt => [ '427',  1257 ],
 lv => [ '426', 1257 ],
 nl => [ '413', 1252 ],
+no => [ '414', 1252 ],
 pl => [ '415', 1250 ],
 pt_BR => [ '416', 1252 ],
 pt => [ '816', 1252 ],
 ro =>  [ '418', 1250 ],
 ru =>  [ '419', 1251 ],
+sk =>  [ '41b', 1250 ],
 sv => [ '41d', 1252 ],
+tr => [ '41f', 1254 ],
 uk => [ '422', 1251 ],
 zh_CN => [ '804', 936 ],
+zh_TW => [ '404', 950 ],
 );
 
 mkdir "$dir\\..\\locale" if ! -d "$dir\\..\\locale";
