@@ -1,12 +1,13 @@
 // astro.cpp
 //
-// Copyright (C) 2001-2006, Chris Laurel <claurel@shatters.net>
+// Copyright (C) 2001-2009, the Celestia Development Team
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either version 2
 // of the License, or (at your option) any later version.
 
+#include <cstring>
 #include <cmath>
 #include <iomanip>
 #include <cstdio>
@@ -17,12 +18,6 @@
 #include "astro.h"
 #include <celutil/util.h>
 
-#ifndef TARGET_OS_MAC
-#ifdef __GNUC__
-#include <langinfo.h>
-#endif
-#endif
-
 using namespace std;
 
 const double astro::speedOfLight = 299792.458; // km/s
@@ -36,11 +31,34 @@ const double astro::SolarMass = 1.989e30;
 const double astro::EarthMass = 5.976e24;
 const double astro::LunarMass = 7.354e22;
 
+const double astro::SOLAR_IRRADIANCE  = 1367.6;        // Watts / m^2
+const double astro::SOLAR_POWER       =    3.8462e26;  // Watts
+
 // Angle between J2000 mean equator and the ecliptic plane.
 // 23 deg 26' 21".448 (Seidelmann, _Explanatory Supplement to the
 // Astronomical Almanac_ (1992), eqn 3.222-1.
 const double astro::J2000Obliquity = degToRad(23.4392911);
 
+static const Quatd ECLIPTIC_TO_EQUATORIAL_ROTATION =
+    Quatd::xrotation(-astro::J2000Obliquity);
+static const Mat3d ECLIPTIC_TO_EQUATORIAL_MATRIX = ECLIPTIC_TO_EQUATORIAL_ROTATION.toMatrix3();
+
+// Equatorial to galactic coordinate transformation
+// North galactic pole at:
+// RA 12h 51m 26.282s (192.85958 deg)
+// Dec 27 d 07' 42.01" (27.1283361 deg)
+// Zero longitude at position angle 122.932
+// (J2000 coordinates)
+static const double GALACTIC_NODE = 282.85958;
+static const double GALACTIC_INCLINATION = 90.0 - 27.1283361;
+static const double GALACTIC_LONGITUDE_AT_NODE = 32.932;
+
+static const Quatd EQUATORIAL_TO_GALACTIC_ROTATION =
+    Quatd::zrotation(degToRad(GALACTIC_NODE)) *
+    Quatd::xrotation(degToRad(GALACTIC_INCLINATION)) *
+    Quatd::zrotation(degToRad(-GALACTIC_LONGITUDE_AT_NODE));
+static const Mat3d EQUATORIAL_TO_GALACTIC_MATRIX = EQUATORIAL_TO_GALACTIC_ROTATION.toMatrix3();
+    
 // epoch B1950: 22:09 UT on 21 Dec 1949
 #define B1950         2433282.423
 
@@ -84,11 +102,14 @@ static const LeapSecondRecord LeapSeconds[] =
     { 31, 2450630.5 }, // 1 Jul 1997
     { 32, 2451179.5 }, // 1 Jan 1999
     { 33, 2453736.5 }, // 1 Jan 2006
+    { 34, 2454832.5 }, // 1 Jan 2009
 };
 
 
+#if !defined(__GNUC__) || defined(_WIN32)
 static const char* MonthAbbrList[12] =
 { "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
+#endif
 
 
 static Mat3d equatorialToCelestiald = Mat3d::xrotation(astro::J2000Obliquity);
@@ -382,6 +403,44 @@ double astro::meanEclipticObliquity(double jd)
     return J2000Obliquity - de;
 }
 
+
+/*! Return a quaternion giving the transformation from the J2000 ecliptic
+ *  coordinate system to the J2000 Earth equatorial coordinate system.
+ */
+Quatd astro::eclipticToEquatorial()
+{
+    return ECLIPTIC_TO_EQUATORIAL_ROTATION;
+}
+
+
+/*! Rotate a vector in the J2000 ecliptic coordinate system to
+ *  the J2000 Earth equatorial coordinate system.
+ */
+Vec3d astro::eclipticToEquatorial(const Vec3d& v)
+{
+    return v * ECLIPTIC_TO_EQUATORIAL_MATRIX;
+}
+
+
+/*! Return a quaternion giving the transformation from the J2000 Earth
+ *  equatorial coordinate system to the galactic coordinate system.
+ */
+Quatd astro::equatorialToGalactic()
+{
+    return EQUATORIAL_TO_GALACTIC_ROTATION;
+}
+
+
+/*! Rotate a vector int the J2000 Earth equatorial coordinate system to
+ *  the galactic coordinate system.
+ */
+Vec3d astro::equatorialToGalactic(const Vec3d& v)
+{
+    return v * EQUATORIAL_TO_GALACTIC_MATRIX;
+}
+
+
+
 astro::Date::Date()
 {
     year = 0;
@@ -412,7 +471,6 @@ astro::Date::Date(double jd)
 {
     int64 a = (int64) floor(jd + 0.5);
     wday = (a + 1) % 7;
-    if (wday < 0) wday += 7;
     double c;
     if (a < 2299161)
     {
@@ -447,19 +505,13 @@ astro::Date::Date(double jd)
     tzname = "UTC";
 }
 
-#ifndef TARGET_OS_MAC
-#ifdef __GNUC__	
-bool astro::Date::utf8Locale = false;
-bool astro::Date::utf8LocaleSet = false;
-iconv_t astro::Date::utf8Iconv;
-#endif
-#endif
-
 const char* astro::Date::toCStr(Format format) const
 {
     static char date[255];
 
-#ifdef __GNUC__
+    // MinGW's libraries don't have the tm_gmtoff and tm_zone fields for
+    // struct tm.
+#if defined(__GNUC__) && !defined(_WIN32)
     struct tm cal_time;
     memset(&cal_time, 0, sizeof(cal_time));
     cal_time.tm_year = year-1900;
@@ -470,9 +522,14 @@ const char* astro::Date::toCStr(Format format) const
     cal_time.tm_sec = (int)seconds;
     cal_time.tm_wday = wday;
     cal_time.tm_gmtoff = utc_offset;
+#if defined(TARGET_OS_MAC) || defined(__FreeBSD__)
+    // tm_zone is a non-const string field on the Mac and FreeBSD (why?)
+    cal_time.tm_zone = const_cast<char*>(tzname.c_str());
+#else
     cal_time.tm_zone = tzname.c_str();
+#endif
 
-    char* strftime_format;
+    const char* strftime_format;
     switch(format)
     {
     case Locale:
@@ -481,36 +538,12 @@ const char* astro::Date::toCStr(Format format) const
     case TZName:
         strftime_format = "%Y %b %d %H:%M:%S %Z";
         break;
-    case UTCOffset:
+    default:
         strftime_format = "%Y %b %d %H:%M:%S %z";
         break;
     }
 
-    size_t in = strftime(date, sizeof(date), strftime_format, &cal_time);
-
-#ifndef TARGET_OS_MAC
-    // The string returned by strftime is in the current locale's charset
-    // which may not be UTF-8
-    if (!astro::Date::utf8LocaleSet)
-    {
-        // Checks the current locale's charset and if needed sets up
-        // an iconv handle
-        astro::Date::utf8Locale = !strcmp(nl_langinfo(CODESET), "UTF-8");
-        if (!astro::Date::utf8Locale) 
-            astro::Date::utf8Iconv = iconv_open("UTF-8", nl_langinfo(CODESET));
-        astro::Date::utf8LocaleSet = true;
-    }
-
-    if (!astro::Date::utf8Locale)
-    {
-        static char utf8Date[255];
-        char* outBuff = utf8Date;
-        char* inBuff = date;
-        size_t out = 255;
-        iconv(astro::Date::utf8Iconv, &inBuff, &in, &outBuff, &out);
-        return utf8Date;
-    }
-#endif
+    strftime(date, sizeof(date), strftime_format, &cal_time);
 #else
     switch(format)
     {
@@ -608,6 +641,24 @@ bool astro::parseDate(const string& s, astro::Date& date)
     return false;
 }
 
+
+astro::Date
+astro::Date::systemDate()
+{
+    time_t t = time(NULL);
+    struct tm *gmt = gmtime(&t);
+    astro::Date d;
+    d.year = gmt->tm_year + 1900;
+    d.month = gmt->tm_mon + 1;
+    d.day = gmt->tm_mday;
+    d.hour = gmt->tm_hour;
+    d.minute = gmt->tm_min;
+    d.seconds = (int) gmt->tm_sec;
+    
+    return d;
+}
+
+
 ostream& operator<<(ostream& s, const astro::Date d)
 {
     s << d.toCStr();
@@ -756,7 +807,7 @@ astro::TDBtoLocal(double tdb)
             d.minute = localt->tm_min;
             d.seconds = (int) localt->tm_sec;
             d.wday = localt->tm_wday;
-        #ifdef __GNUC__
+        #if defined(__GNUC__) && !defined(_WIN32)
             d.utc_offset = localt->tm_gmtoff;
             d.tzname = localt->tm_zone;
         #else
