@@ -14,14 +14,9 @@
 #include <string>
 #include <cmath>
 #include <celmath/vecmath.h>
+#include <celmath/quaternion.h>
 #include <celengine/univcoord.h>
 
-#ifndef TARGET_OS_MAC
-#ifdef __GNUC__
-#include <iconv.h>
-#endif
-#endif
-
 #define SOLAR_ABSMAG  4.83f
 #define LN_MAG        1.085736
 #define LY_PER_PARSEC 3.26167
@@ -50,6 +45,8 @@ namespace astro
         const char* toCStr(Format format = Locale) const;
 
         operator double() const;
+        
+        static Date systemDate();
 
 
     public:
@@ -62,32 +59,10 @@ namespace astro
         int utc_offset;     // offset from utc in seconds
         std::string tzname; // timezone name
         double seconds;
-
-#ifndef TARGET_OS_MAC
-#ifdef __GNUC__
-    private:
-        // Static members used to store locale related UTF-8 information
-        static bool utf8Locale;
-        static bool utf8LocaleSet;
-        static iconv_t utf8Iconv;
-#endif
-#endif
     };
 
     bool parseDate(const std::string&, Date&);
 
-    enum CoordinateSystem
-    {
-        Universal       = 0,
-        Ecliptical      = 1,
-        Equatorial      = 2,
-        Geographic      = 3,
-        ObserverLocal   = 4,
-        PhaseLock       = 5,
-        Chase           = 6,
-    };
-
-
     // Time scale conversions
     // UTC - Coordinated Universal Time
     // TAI - International Atomic Time
@@ -192,6 +167,11 @@ namespace astro
     Point3f equatorialToCelestialCart(float ra, float dec, float distance);
     Point3d equatorialToCelestialCart(double ra, double dec, double distance);
 
+    Quatd eclipticToEquatorial();
+    Vec3d eclipticToEquatorial(const Vec3d& v);
+    Quatd equatorialToGalactic();
+    Vec3d equatorialToGalactic(const Vec3d& v);
+
     void anomaly(double meanAnomaly, double eccentricity,
                  double& trueAnomaly, double& eccentricAnomaly);
     double meanEclipticObliquity(double jd);
@@ -204,6 +184,9 @@ namespace astro
     extern const double LunarMass;
 
     extern const double J2000Obliquity;
+
+    extern const double SOLAR_IRRADIANCE;
+    extern const double SOLAR_POWER;  // in Watts
 };
 
 // Convert a date structure to a Julian date
