@@ -670,7 +670,10 @@ Command* CommandParser::parseCommand()
         rep.setColor(color);
         rep.setLabel(label);        
 
-        cmd = new CommandMark(object, rep);
+        bool occludable = true;
+        paramList->getBoolean("occludable", occludable);
+
+        cmd = new CommandMark(object, rep, occludable);
     }
     else if (commandName == "unmark")
     {
@@ -761,6 +764,13 @@ Command* CommandParser::parseCommand()
         Color color((float) colorv.x, (float) colorv.y, (float) colorv.z);
         cmd = new CommandSetLabelColor(item, color);
     }
+    else if (commandName == "settextcolor")
+    {
+        Vec3d colorv(1.0f, 1.0f, 1.0f);
+        paramList->getVector("color", colorv);
+        Color color((float) colorv.x, (float) colorv.y, (float) colorv.z);
+        cmd = new CommandSetTextColor(color);
+    }
     else
     {
         error("Unknown command name '" + commandName + "'");
