@@ -27,7 +27,7 @@ bool dsoAbsoluteMagnitudePredicate(DeepSkyObject* const & _dso, const float absM
 bool dsoStraddlesNodesPredicate(const Point3d& cellCenterPos, DeepSkyObject* const & _dso, const float)
 {
     //checks if this dso's radius straddles child nodes
-    float dsoRadius    = _dso->getRadius();
+    float dsoRadius    = _dso->getBoundingSphereRadius();
 
     Point3d dsoPos     = _dso->getPosition();
 
@@ -70,26 +70,24 @@ template<> DynamicDSOOctree::ExclusionFactorDecayFunction*
 template<>
 void DSOOctree::processVisibleObjects(DSOHandler&    processor,
                                       const Point3d& obsPosition,
-                                      const Planef*  frustumPlanes,
+                                      const Planed*  frustumPlanes,
                                       float          limitingFactor,
                                       double         scale) const
 {
     // See if this node lies within the view frustum
 
-        // Test the cubic octree node against each one of the five
-        // planes that define the infinite view frustum.
-        for (int i=0; i<5; ++i)
-        {
-            const Planef* plane = frustumPlanes + i;
-                  double  r     = scale * (abs(plane->normal.x) +
-                                           abs(plane->normal.y) +
-                                           abs(plane->normal.z));
+    // Test the cubic octree node against each one of the five
+    // planes that define the infinite view frustum.
+    for (int i = 0; i < 5; ++i)
+    {
+        const Planed* plane = frustumPlanes + i;
+        double  r     = scale * (abs(plane->normal.x) +
+                                 abs(plane->normal.y) +
+                                 abs(plane->normal.z));
 
-            Vec3d vecDbl((double) plane->normal.x, (double) plane->normal.y, (double) plane->normal.z);
-
-            if (vecDbl * Vec3d(cellCenterPos.x, cellCenterPos.y, cellCenterPos.z) - plane->d < -r)
-                return;
-        }
+        if (plane->normal * Vec3d(cellCenterPos.x, cellCenterPos.y, cellCenterPos.z) - plane->d < -r)
+            return;
+    }
 
     // Compute the distance to node; this is equal to the distance to
     // the cellCenterPos of the node minus the boundingRadius of the node, scale * SQRT3.
@@ -104,7 +102,7 @@ void DSOOctree::processVisibleObjects(DSOHandler&    processor,
         float  absMag      = _obj->getAbsoluteMagnitude();
         if (absMag < dimmest)
         {
-            double distance    = obsPosition.distanceTo(_obj->getPosition()) - _obj->getRadius();
+            double distance    = obsPosition.distanceTo(_obj->getPosition()) - _obj->getBoundingSphereRadius();
             float appMag = (float) ((distance >= 32.6167) ? astro::absToAppMag((double) absMag, distance) : absMag);
 
             if ( appMag < limitingFactor)
@@ -156,7 +154,7 @@ void DSOOctree::processCloseObjects(DSOHandler&    processor,
         if (obsPosition.distanceToSquared(_obj->getPosition()) < radiusSquared)    //
         {
             float  absMag      = _obj->getAbsoluteMagnitude();
-            double distance    = obsPosition.distanceTo(_obj->getPosition()) - _obj->getRadius();
+            double distance    = obsPosition.distanceTo(_obj->getPosition()) - _obj->getBoundingSphereRadius();
 
             processor.process(_obj, distance, absMag);
         }
