@@ -1,6 +1,8 @@
 // frame.cpp
 // 
-// Copyright (C) 2003-2006, Chris Laurel <claurel@shatters.net>
+// Reference frame base class.
+//
+// Copyright (C) 2003-2008, Chris Laurel <claurel@shatters.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -13,212 +15,9 @@
 using namespace std;
 
 
-RigidTransform FrameOfReference::toUniversal(const RigidTransform& xform,
-                                             double t) const
-{
-    // Handle the easy case . . .
-    if (coordSys == astro::Universal)
-        return xform;
-    UniversalCoord origin = refObject.getPosition(t);
-
-    if (coordSys == astro::Geographic)
-    {
-        Quatd rotation(1, 0, 0, 0);
-        switch (refObject.getType())
-        {
-        case Selection::Type_Body:
-            rotation = refObject.body()->getEclipticalToBodyFixed(t);
-            break;
-        case Selection::Type_Star:
-            rotation = refObject.star()->getRotationModel()->orientationAtTime(t);
-            break;
-        case Selection::Type_Location:
-            if (refObject.location()->getParentBody() != NULL)
-                rotation = refObject.location()->getParentBody()->getEclipticalToBodyFixed(t);
-            break;
-        default:
-            break;
-        }
-
-        Point3d p = (Point3d) xform.translation * rotation.toMatrix4();
-        return RigidTransform(origin + Vec3d(p.x, p.y, p.z),
-                              xform.rotation * rotation);
-    }
-    else if (coordSys == astro::PhaseLock)
-    {
-        Mat3d m;
-        Vec3d lookDir = refObject.getPosition(t) - targetObject.getPosition(t);
-        lookDir.normalize();
-
-        switch (refObject.getType())
-        {
-        case Selection::Type_Body:
-            {
-                Body* body = refObject.body();
-                Vec3d axisDir = Vec3d(0, 1, 0) * body->getEclipticalToEquatorial(t).toMatrix3();
-                Vec3d v = axisDir ^ lookDir;
-                v.normalize();
-                Vec3d u = lookDir ^ v;
-                m = Mat3d(v, u, lookDir);
-            }
-            break;
-        case Selection::Type_Star:
-            {
-                Star* star = refObject.star();
-                Vec3d axisDir = Vec3d(0, 1, 0) * star->getRotationModel()->equatorOrientationAtTime(t).toMatrix3();
-                Vec3d v = axisDir ^ lookDir;
-                v.normalize();
-                Vec3d u = lookDir ^ v;
-                m = Mat3d(v, u, lookDir);
-            }
-        default:
-            return xform;
-        }
-
-        Point3d p = (Point3d) xform.translation * m;
-
-        return RigidTransform(origin + Vec3d(p.x, p.y, p.z),
-                              xform.rotation * Quatd(m));
-    }
-    else if (coordSys == astro::Chase)
-    {
-        Mat3d m;
-
-        switch (refObject.getType())
-        {
-        case Selection::Type_Body:
-            {
-                Body* body = refObject.body();
-                Vec3d lookDir = body->getOrbit()->positionAtTime(t) -
-                    body->getOrbit()->positionAtTime(t - 1.0 / 1440.0);
-                Vec3d axisDir = Vec3d(0, 1, 0) * body->getEclipticalToEquatorial(t).toMatrix3();
-                lookDir.normalize();
-                Vec3d v = lookDir ^ axisDir;
-                v.normalize();
-                Vec3d u = v ^ lookDir;
-                m = Mat3d(v, u, -lookDir);
-            }
-            break;
-        default:
-            return xform;
-        }
-
-        Point3d p = (Point3d) xform.translation * m;
-
-        return RigidTransform(origin + Vec3d(p.x, p.y, p.z),
-                              xform.rotation * Quatd(m));
-    }
-    else
-    {
-        return RigidTransform(origin + xform.translation, xform.rotation);
-    }
-}
-
-
-RigidTransform FrameOfReference::fromUniversal(const RigidTransform& xform,
-                                               double t) const
-{
-    // Handle the easy case . . .
-    if (coordSys == astro::Universal)
-        return xform;
-    UniversalCoord origin = refObject.getPosition(t);
-
-    if (coordSys == astro::Geographic)
-    {
-        Quatd rotation(1, 0, 0, 0);
-        switch (refObject.getType())
-        {
-        case Selection::Type_Body:
-            rotation = refObject.body()->getEclipticalToBodyFixed(t);
-            break;
-        case Selection::Type_Star:
-            rotation = refObject.star()->getRotationModel()->orientationAtTime(t);
-            break;
-        case Selection::Type_Location:
-            if (refObject.location()->getParentBody() != NULL)
-                rotation = refObject.location()->getParentBody()->getEclipticalToBodyFixed(t);
-            break;
-        default:
-            break;
-        }
-        Vec3d v = (xform.translation - origin) * (~rotation).toMatrix4();
-        
-        return RigidTransform(UniversalCoord(v.x, v.y, v.z),
-                              xform.rotation * ~rotation);
-    }
-    else if (coordSys == astro::PhaseLock)
-    {
-        Mat3d m;
-        Vec3d lookDir = refObject.getPosition(t) - targetObject.getPosition(t);
-        lookDir.normalize();
-
-        switch (refObject.getType())
-        {
-        case Selection::Type_Body:
-            {
-                Body* body = refObject.body();
-                Vec3d axisDir = Vec3d(0, 1, 0) * body->getEclipticalToEquatorial(t).toMatrix3();
-                Vec3d v = axisDir ^ lookDir;
-                v.normalize();
-                Vec3d u = lookDir ^ v;
-                m = Mat3d(v, u, lookDir);
-            }
-            break;
-
-        case Selection::Type_Star:
-            {
-                Star* star = refObject.star();
-                Vec3d axisDir = Vec3d(0, 1, 0) * star->getRotationModel()->equatorOrientationAtTime(t).toMatrix3();
-                Vec3d v = axisDir ^ lookDir;
-                v.normalize();
-                Vec3d u = lookDir ^ v;
-                m = Mat3d(v, u, lookDir);
-            }
-
-        default:
-            return xform;
-        }
-
-        Vec3d v = (xform.translation - origin) * m.transpose();
-
-        return RigidTransform(UniversalCoord(v.x, v.y, v.z),
-                              xform.rotation * ~Quatd(m));
-    }
-    else if (coordSys == astro::Chase)
-    {
-        Mat3d m;
-
-        switch (refObject.getType())
-        {
-        case Selection::Type_Body:
-            {
-                Body* body = refObject.body();
-                Vec3d lookDir = body->getOrbit()->positionAtTime(t) -
-                    body->getOrbit()->positionAtTime(t - 1.0 / 1440.0);
-                Vec3d axisDir = Vec3d(0, 1, 0) * body->getEclipticalToEquatorial(t).toMatrix3();
-                lookDir.normalize();
-                Vec3d v = lookDir ^ axisDir;
-                v.normalize();
-                Vec3d u = v ^ lookDir;
-                m = Mat3d(v, u, -lookDir);
-            }
-            break;
-
-        default:
-            return xform;
-        }
-
-        Vec3d v = (xform.translation - origin) * m.transpose();
-
-        return RigidTransform(UniversalCoord(v.x, v.y, v.z),
-                              xform.rotation * ~Quatd(m));
-    }
-    else
-    {
-        return RigidTransform(xform.translation.difference(origin),
-                              xform.rotation);
-    }
-}
+// Velocity for two-vector frames is computed by differentiation; units
+// are Julian days.
+static const double ANGULAR_VELOCITY_DIFF_DELTA = 1.0 / 1440.0;
 
 
 /*** ReferenceFrame ***/
@@ -249,35 +48,95 @@ ReferenceFrame::release() const
 }
 
 
-// TODO: Not correct; requires BigFix * double multiplication
-UniversalCoord
-ReferenceFrame::convertFrom(const UniversalCoord& uc, double tjd) const
+// High-precision rotation using 64.64 fixed point path. Rotate uc by
+// the rotation specified by unit quaternion q.
+static UniversalCoord rotate(const UniversalCoord& uc, const Quatd& q)
 {
-    UniversalCoord center = centerObject.getPosition(tjd);
-    Vec3d relative = uc - center;
-
-    return center + relative * getOrientation(tjd).toMatrix3();
+    Mat3d r = q.toMatrix3();
+    UniversalCoord uc1;
+    
+    uc1.x = uc.x * BigFix(r[0].x) + uc.y * BigFix(r[1].x) + uc.z * BigFix(r[2].x);
+    uc1.y = uc.x * BigFix(r[0].y) + uc.y * BigFix(r[1].y) + uc.z * BigFix(r[2].y);
+    uc1.z = uc.x * BigFix(r[0].z) + uc.y * BigFix(r[1].z) + uc.z * BigFix(r[2].z);
+    
+    return uc1;
 }
 
 
-// TODO: Not correct; requires BigFix * double multiplication
+/*! Convert from universal coordinates to frame coordinates. This method
+ *  uses 64.64 fixed point arithmetic in conversion, and is thus /much/ slower
+ *  than convertFromAstrocentric(), which works with double precision
+ *  floating points values. For cases when the bodies are all in the same
+ *  solar system, convertFromAstrocentric() should be used.
+ */
 UniversalCoord
-ReferenceFrame::convertTo(const UniversalCoord& uc, double tjd) const
+ReferenceFrame::convertFromUniversal(const UniversalCoord& uc, double tjd) const
 {
-    UniversalCoord center = centerObject.getPosition(tjd);
-    Vec3d relative = uc - center;
+    UniversalCoord uc1 = uc.difference(centerObject.getPosition(tjd));
+    return rotate(uc1, conjugate(getOrientation(tjd)));
+}
 
-    return center + relative * conjugate(getOrientation(tjd)).toMatrix3();
+
+Quatd
+ReferenceFrame::convertFromUniversal(const Quatd& q, double tjd) const
+{
+    return q * conjugate(getOrientation(tjd));
+}
+
+
+/*! Convert from local coordinates to universal coordinates. This method
+ *  uses 64.64 fixed point arithmetic in conversion, and is thus /much/ slower
+ *  than convertFromAstrocentric(), which works with double precision
+ *  floating points values. For cases when the bodies are all in the same
+ *  solar system, convertFromAstrocentric() should be used.
+ *
+ *  To get the position of a solar system object in universal coordinates,
+ *  it usually suffices to get the astrocentric position and then add that
+ *  to the position of the star in universal coordinates. This avoids any
+ *  expensive high-precision multiplication.
+ */
+UniversalCoord
+ReferenceFrame::convertToUniversal(const UniversalCoord& uc, double tjd) const
+{
+    return centerObject.getPosition(tjd) + rotate(uc, getOrientation(tjd));
+}
+
+
+Quatd
+ReferenceFrame::convertToUniversal(const Quatd& q, double tjd) const
+{
+    return q * getOrientation(tjd);
 }
 
 
 Point3d
 ReferenceFrame::convertFromAstrocentric(const Point3d& p, double tjd) const
 {
-    Point3d center;
     if (centerObject.getType() == Selection::Type_Body)
     {
-        Point3d center = centerObject.body()->getHeliocentricPosition(tjd);
+        Point3d center = centerObject.body()->getAstrocentricPosition(tjd);
+        return Point3d(0.0, 0.0, 0.0) + (p - center) * conjugate(getOrientation(tjd)).toMatrix3();
+    }
+    else if (centerObject.getType() == Selection::Type_Star)
+    {
+        return p * conjugate(getOrientation(tjd)).toMatrix3();
+    }
+    else
+    {
+        // TODO:
+        // bad if the center object is a galaxy
+        // what about locations?
+        return Point3d(0.0, 0.0, 0.0);
+    }
+}
+
+
+Point3d
+ReferenceFrame::convertToAstrocentric(const Point3d& p, double tjd) const
+{
+    if (centerObject.getType() == Selection::Type_Body)
+    {
+        Point3d center = centerObject.body()->getAstrocentricPosition(tjd);
         return center + p * getOrientation(tjd).toMatrix3();
     }
     else if (centerObject.getType() == Selection::Type_Star)
@@ -290,10 +149,12 @@ ReferenceFrame::convertFromAstrocentric(const Point3d& p, double tjd) const
         // bad if the center object is a galaxy
         // what about locations?
         return Point3d(0.0, 0.0, 0.0);
-    }
+    }    
 }
 
 
+/*! Return the object that is the defined origin of the reference frame.
+ */
 Selection
 ReferenceFrame::getCenter() const
 {
@@ -301,6 +162,22 @@ ReferenceFrame::getCenter() const
 }
 
 
+Vec3d
+ReferenceFrame::getAngularVelocity(double tjd) const
+{
+	Quatd q0 = getOrientation(tjd);
+	Quatd q1 = getOrientation(tjd + ANGULAR_VELOCITY_DIFF_DELTA);
+	Quatd dq = ~q0 * q1;
+
+	if (fabs(dq.w) > 0.99999999)
+		return Vec3d(0.0, 0.0, 0.0);
+
+	Vec3d v(dq.x, dq.y, dq.z);
+	v.normalize();
+	return v * (2.0 * acos(dq.w) / ANGULAR_VELOCITY_DIFF_DELTA);
+}
+
+
 unsigned int
 ReferenceFrame::nestingDepth(unsigned int maxDepth, FrameType frameType) const
 {
@@ -326,16 +203,17 @@ getFrameDepth(const Selection& sel, unsigned int depth, unsigned int maxDepth,
 
     unsigned int orbitFrameDepth = depth;
     unsigned int bodyFrameDepth = depth;
-    if (body->getOrbitFrame() != NULL && frameType == ReferenceFrame::PositionFrame)
+    // TODO: need to check /all/ orbit frames of body
+    if (body->getOrbitFrame(0.0) != NULL && frameType == ReferenceFrame::PositionFrame)
     {
-        orbitFrameDepth = body->getOrbitFrame()->nestingDepth(depth + 1, maxDepth, frameType);
+        orbitFrameDepth = body->getOrbitFrame(0.0)->nestingDepth(depth + 1, maxDepth, frameType);
         if (orbitFrameDepth > maxDepth)
             return orbitFrameDepth;
     }
         
-    if (body->getBodyFrame() != NULL && frameType == ReferenceFrame::OrientationFrame)
+    if (body->getBodyFrame(0.0) != NULL && frameType == ReferenceFrame::OrientationFrame)
     {
-        bodyFrameDepth = body->getBodyFrame()->nestingDepth(depth + 1, maxDepth, frameType);
+        bodyFrameDepth = body->getBodyFrame(0.0)->nestingDepth(depth + 1, maxDepth, frameType);
     }
 
     return max(orbitFrameDepth, bodyFrameDepth);
@@ -351,11 +229,17 @@ J2000EclipticFrame::J2000EclipticFrame(Selection center) :
 }
 
 
+bool
+J2000EclipticFrame::isInertial() const
+{
+	return true;
+}
+
 
 unsigned int
 J2000EclipticFrame::nestingDepth(unsigned int depth,
                                  unsigned int maxDepth,
-                                 FrameType frameType) const
+                                 FrameType) const
 {
     return getFrameDepth(getCenter(), depth, maxDepth, PositionFrame);
 }
@@ -376,10 +260,17 @@ J2000EquatorFrame::getOrientation(double /* tjd */) const
 }
 
 
+bool
+J2000EquatorFrame::isInertial() const
+{
+	return true;
+}
+
+
 unsigned int
 J2000EquatorFrame::nestingDepth(unsigned int depth,
                                 unsigned int maxDepth,
-                                FrameType frameType) const
+                                FrameType) const
 {
     return getFrameDepth(getCenter(), depth, maxDepth, PositionFrame);
 }
@@ -404,7 +295,7 @@ BodyFixedFrame::getOrientation(double tjd) const
     switch (fixObject.getType())
     {
     case Selection::Type_Body:
-        return yrot180 * fixObject.body()->getEclipticalToBodyFixed(tjd);
+        return yrot180 * fixObject.body()->getEclipticToBodyFixed(tjd);
     case Selection::Type_Star:
         return yrot180 * fixObject.star()->getRotationModel()->orientationAtTime(tjd);
     default:
@@ -413,10 +304,32 @@ BodyFixedFrame::getOrientation(double tjd) const
 }
 
 
+Vec3d
+BodyFixedFrame::getAngularVelocity(double tjd) const
+{
+	switch (fixObject.getType())
+	{
+	case Selection::Type_Body:
+		return fixObject.body()->getAngularVelocity(tjd);
+	case Selection::Type_Star:
+		return fixObject.star()->getRotationModel()->angularVelocityAtTime(tjd);
+	default:
+		return Vec3d(0.0, 0.0, 0.0);
+	}
+}
+
+
+bool
+BodyFixedFrame::isInertial() const
+{
+	return false;
+}
+
+
 unsigned int
 BodyFixedFrame::nestingDepth(unsigned int depth,
                              unsigned int maxDepth,
-                             FrameType frameType) const
+                             FrameType) const
 {
     unsigned int n = getFrameDepth(getCenter(), depth, maxDepth, PositionFrame);
     if (n > maxDepth)
@@ -437,7 +350,7 @@ BodyMeanEquatorFrame::BodyMeanEquatorFrame(Selection center,
                                            Selection obj) :
     ReferenceFrame(center),
     equatorObject(obj),
-    freezeEpoch(0.0),
+    freezeEpoch(astro::J2000),
     isFrozen(false)
 {
 }
@@ -457,13 +370,12 @@ BodyMeanEquatorFrame::BodyMeanEquatorFrame(Selection center,
 Quatd
 BodyMeanEquatorFrame::getOrientation(double tjd) const
 {
-    double t = isFrozen ? tjd : freezeEpoch;
+    double t = isFrozen ? freezeEpoch : tjd;
 
-    // TODO: need to consider frame of object
     switch (equatorObject.getType())
     {
     case Selection::Type_Body:
-        return equatorObject.body()->getRotationModel()->equatorOrientationAtTime(t);
+        return equatorObject.body()->getEclipticToEquatorial(t);
     case Selection::Type_Star:
         return equatorObject.star()->getRotationModel()->equatorOrientationAtTime(t);
     default:
@@ -472,10 +384,56 @@ BodyMeanEquatorFrame::getOrientation(double tjd) const
 }
 
 
+Vec3d
+BodyMeanEquatorFrame::getAngularVelocity(double tjd) const
+{
+	if (isFrozen)
+	{
+		return Vec3d(0.0, 0.0, 0.0);
+	}
+	else
+	{
+        if (equatorObject.body() != NULL)
+        {
+            return equatorObject.body()->getBodyFrame(tjd)->getAngularVelocity(tjd);
+        }
+        else
+        {
+            return Vec3d(0.0, 0.0, 0.0);
+        }
+	}
+}
+
+
+bool
+BodyMeanEquatorFrame::isInertial() const
+{
+	if (isFrozen)
+	{
+		return true;
+	}
+	else
+	{
+		// Although the mean equator of an object may vary slightly due to precession,
+		// treat it as an inertial frame as long as the body frame of the object is
+		// also inertial.
+		if (equatorObject.body() != NULL)
+		{
+            // TIMELINE-TODO: isInertial must take a time argument.
+			return equatorObject.body()->getBodyFrame(0.0)->isInertial();
+		}
+        else
+        {
+            return true;
+        }
+	}
+}
+
+
 unsigned int
 BodyMeanEquatorFrame::nestingDepth(unsigned int depth,
                                    unsigned int maxDepth,
-                                   FrameType frameType) const
+                                   FrameType) const
 {
     // Test origin and equator object (typically the same) frames
     unsigned int n =  getFrameDepth(getCenter(), depth, maxDepth, PositionFrame);
@@ -496,7 +454,10 @@ BodyMeanEquatorFrame::nestingDepth(unsigned int depth,
 CachingFrame::CachingFrame(Selection _center) :
     ReferenceFrame(_center),
     lastTime(-1.0e50),
-    lastOrientation(1.0)
+    lastOrientation(1.0),
+	lastAngularVelocity(0.0, 0.0, 0.0),
+	orientationCacheValid(false),
+	angularVelocityCacheValid(false)
 {
 }
 
@@ -504,19 +465,68 @@ CachingFrame::CachingFrame(Selection _center) :
 Quatd
 CachingFrame::getOrientation(double tjd) const
 {
-    if (tjd == lastTime)
-    {
-        return lastOrientation;
-    }
-    else
-    {
-        lastTime = tjd;
-        lastOrientation = computeOrientation(tjd);
-        return lastOrientation;
-    }
+	if (tjd != lastTime)
+	{
+		lastTime = tjd;
+		lastOrientation = computeOrientation(tjd);
+		orientationCacheValid = true;
+		angularVelocityCacheValid = false;
+	}
+	else if (!orientationCacheValid)
+	{
+		lastOrientation = computeOrientation(tjd);
+		orientationCacheValid = true;
+	}
+
+	return lastOrientation;
 }
 
 
+Vec3d CachingFrame::getAngularVelocity(double tjd) const
+{
+	if (tjd != lastTime)
+	{
+		lastTime = tjd;
+		lastAngularVelocity = computeAngularVelocity(tjd);
+		orientationCacheValid = false;
+		angularVelocityCacheValid = true;
+	}
+	else if (!angularVelocityCacheValid)
+	{
+		lastAngularVelocity = computeAngularVelocity(tjd);
+		angularVelocityCacheValid = true;
+	}
+
+	return lastAngularVelocity;
+}
+
+
+/*! Calculate the angular velocity at the specified time (units are
+ *  radians / Julian day.) The default implementation just
+ *  differentiates the orientation.
+ */
+Vec3d CachingFrame::computeAngularVelocity(double tjd) const
+{
+	Quatd q0 = getOrientation(tjd);
+
+	// Call computeOrientation() instead of getOrientation() so that we
+	// don't affect the cached value. 
+	// TODO: check the valid ranges of the frame to make sure that
+	// jd+dt is still in range.
+	Quatd q1 = computeOrientation(tjd + ANGULAR_VELOCITY_DIFF_DELTA);
+
+	Quatd dq = ~q0 * q1;
+
+	if (fabs(dq.w) > 0.99999999)
+		return Vec3d(0.0, 0.0, 0.0);
+
+	Vec3d v(dq.x, dq.y, dq.z);
+	v.normalize();
+	return v * (2.0 * acos(dq.w) / ANGULAR_VELOCITY_DIFF_DELTA);
+}
+
+
+
 /*** TwoVectorFrame ***/
 
 // Minimum angle permitted between primary and secondary axes of
@@ -625,10 +635,20 @@ TwoVectorFrame::computeOrientation(double tjd) const
 }
 
 
+bool
+TwoVectorFrame::isInertial() const
+{
+	// Although it's possible to specify an inertial two-vector frame, we won't
+	// bother trying to distinguish these cases: all two-vector frames will be
+	// treated as non-inertial.
+	return true;
+}
+
+
 unsigned int
 TwoVectorFrame::nestingDepth(unsigned int depth,
                              unsigned int maxDepth,
-                             FrameType frameType) const
+                             FrameType) const
 {
     // Check nesting of the origin object as well as frames references by
     // the primary and secondary axes.
@@ -746,10 +766,9 @@ FrameVector::direction(double tjd) const
         break;
 
     case RelativeVelocity:
-        // TODO: add getVelocity() method to selection
         {
-            Vec3d v0 = observer.getPosition(tjd) - observer.getPosition(tjd - 1.0 / 1440.0);
-            Vec3d v1 = target.getPosition(tjd) - target.getPosition(tjd - 1.0 / 1440.0);
+			Vec3d v0 = observer.getVelocity(tjd);
+			Vec3d v1 = target.getVelocity(tjd);
             v = v1 - v0;
         }
         break;
