@@ -7,6 +7,7 @@
 // as published by the Free Software Foundation; either version 2
 // of the License, or (at your option) any later version.
 
+#include <cstring>
 #include <fstream>
 #include <algorithm>
 #include <cstdio>
@@ -83,9 +84,15 @@ static void GalaxyTextureEval(float u, float v, float /*w*/, unsigned char *pixe
         r = 0;
 
     int pixVal = (int) (r * 255.99f);
+#ifdef HDR_COMPRESS
+    pixel[0] = 127;
+    pixel[1] = 127;
+    pixel[2] = 127;
+#else
     pixel[0] = 255;//65;
     pixel[1] = 255;//64;
     pixel[2] = 255;//65;
+#endif
     pixel[3] = pixVal;
 }
 
@@ -211,6 +218,9 @@ bool Galaxy::pick(const Ray3d& ray,
                   double& distanceToPicker,
                   double& cosAngleToBoundCenter) const
 {
+    if (!isVisible())
+        return false;
+    
     // The ellipsoid should be slightly larger to compensate for the fact
     // that blobs are considered points when galaxies are built, but have size
     // when they are drawn.
@@ -380,8 +390,8 @@ void Galaxy::renderGalaxyEllipsoid(const GLContext& context,
     float discSizeInPixels = pixelSize * getRadius() / offset.length();
     unsigned int nRings = (unsigned int) (discSizeInPixels / 4.0f);
     unsigned int nSlices = (unsigned int) (discSizeInPixels / 4.0f);
-    nRings = max(nRings, 100);
-    nSlices = max(nSlices, 100);
+    nRings = max(nRings, 100u);
+    nSlices = max(nSlices, 100u);
 
     VertexProcessor* vproc = context.getVertexProcessor();
     if (vproc == NULL)
@@ -476,62 +486,6 @@ void Galaxy::setLightGain(float lg)
 }
 
 
-void Galaxy::hsv2rgb( float *r, float *g, float *b, float h, float s, float v )
-{
-// r,g,b values are from 0 to 1
-// h = [0,360], s = [0,1], v = [0,1]
-
-   int i;
-   float f, p, q, t;
-
-   if( s == 0 ) {
-       // achromatic (grey)
-       *r = *g = *b = v;
-   return;
-   }
-
-   h /= 60;            // sector 0 to 5
-   i = (int) floorf( h );
-   f = h - (float) i;            // factorial part of h
-   p = v * ( 1 - s );
-   q = v * ( 1 - s * f );
-   t = v * ( 1 - s * ( 1 - f ) );
-
-   switch( i ) {
-   case 0:
-     *r = v;
-     *g = t;
-     *b = p;
-     break;
-   case 1:
-     *r = q;
-     *g = v;
-     *b = p;
-     break;
-   case 2:
-     *r = p;
-     *g = v;
-     *b = t;
-     break;
-   case 3:
-     *r = p;
-     *g = q;
-     *b = v;
-     break;
-   case 4:
-     *r = t;
-     *g = p;
-     *b = v;
-     break;
-   default:
-     *r = v;
-     *g = p;
-     *b = q;
-     break;
-   }
-}
-
-
 GalacticForm* buildGalacticForms(const std::string& filename)
 {
 	Blob b;
@@ -641,7 +595,7 @@ void InitializeForms()
 
         //convert Hue to RGB
 
-        Galaxy::hsv2rgb(&rr, &gg, &bb, hue, 0.20f, 1.0f);
+		DeepSkyObject::hsv2rgb(&rr, &gg, &bb, hue, 0.20f, 1.0f);
         colorTable[i]  = Color(rr, gg, bb);
     }
     // Spiral Galaxies, 7 classical Hubble types
