@@ -29,8 +29,9 @@ public:
 
     // Required for eclipse shadows only--may be able to use
     // distance instead of position.
-    Point3d position;
+    Vec3d position;  // position relative to the lit object
     float apparentSize;
+    bool castsShadows;
 };
 
 class EclipseShadow
@@ -40,6 +41,7 @@ public:
     Vec3f direction;
     float penumbraRadius;
     float umbraRadius;
+    float maxDepth;
 };
 
 class LightingState
