@@ -12,6 +12,7 @@
 
 #include <string>
 #include <celutil/basictypes.h>
+#include <celutil/color.h>
 #include <celmath/vecmath.h>
 
 
@@ -41,6 +42,12 @@ class Location
     std::string getInfoURL() const;
     void setInfoURL(const std::string&);
 
+    bool isLabelColorOverridden() const { return overrideLabelColor; }
+    void setLabelColorOverridden(bool override) { overrideLabelColor = override; }
+
+    Color getLabelColor() const { return labelColor; }
+    void setLabelColor(Color color) { labelColor = color; }
+
     void setParentBody(Body*);
     Body* getParentBody() const;
 
@@ -74,11 +81,14 @@ class Location
         Mensa          = 0x00100000,
         Rima           = 0x00200000,
         Undae          = 0x00400000,
+        Tholus         = 0x00800000, // Small domical mountain or hill
         Reticulum      = 0x01000000,
         Planitia       = 0x02000000,
         Linea          = 0x04000000,
         Fluctus        = 0x08000000,
         Farrum         = 0x10000000,
+        EruptiveCenter = 0x20000000, // Active volcanic centers on Io
+        Insula         = 0x40000000, // Islands
         Other          = 0x80000000,
     };
 
@@ -90,6 +100,8 @@ class Location
     float size;
     float importance;
     uint32 featureType;
+    bool overrideLabelColor;
+    Color labelColor;
     std::string* infoURL;
 };
 
