@@ -15,12 +15,11 @@ using namespace std;
 
 
 Marker::Marker(const Selection& s) :
-    obj(s),
-    size(10.0f),
-    color(Color::White),
-    priority(0),
-    symbol(Diamond),
-    label("")
+    m_object(s),
+    m_priority(0),
+    m_representation(MarkerRepresentation::Diamond),
+    m_occludable(true),
+    m_sizing(ConstantSize)
 {
 }
 
@@ -29,82 +28,130 @@ Marker::~Marker()
 }
 
 
-UniversalCoord Marker::getPosition(double jd) const
+UniversalCoord Marker::position(double jd) const
 {
-    return obj.getPosition(jd);
+    return m_object.getPosition(jd);
 }
 
 
-Selection Marker::getObject() const
+Selection Marker::object() const
 {
-    return obj;
+    return m_object;
 }
 
 
-Color Marker::getColor() const
+int Marker::priority() const
 {
-    return color;
+    return m_priority;
 }
 
 
-void Marker::setColor(Color _color)
+void Marker::setPriority(int priority)
 {
-    color = _color;
+    m_priority = priority;
 }
 
 
-float Marker::getSize() const
+void Marker::setRepresentation(const MarkerRepresentation& rep)
 {
-    return size;
+    m_representation = rep;
 }
 
 
-void Marker::setSize(float _size)
+bool Marker::occludable() const
 {
-    size = _size;
+    return m_occludable;
 }
 
 
-int Marker::getPriority() const
+void Marker::setOccludable(bool occludable)
 {
-    return priority;
+    m_occludable = occludable;
 }
 
 
-void Marker::setPriority(int _priority)
+MarkerSizing Marker::sizing() const
 {
-    priority = _priority;
+    return m_sizing;
 }
 
 
-Marker::Symbol Marker::getSymbol() const
+void Marker::setSizing(MarkerSizing sizing)
 {
-    return symbol;
-}
-
-void Marker::setSymbol(Marker::Symbol _symbol)
-{
-    symbol = _symbol;
+    m_sizing = sizing;
 }
 
 
-string Marker::getLabel() const
+void Marker::render(float size) const
 {
-    return label;
+    m_representation.render(m_sizing == DistanceBasedSize ? size : m_representation.size());
 }
 
 
-void Marker::setLabel(string _label)
+
+static void DrawCircle(float s)
 {
-    label = _label;
+    if (s < 1.0f)
+        s = 1.0f; //  0 and negative values are not allowed in the case of circle markers.
+    else if (s > 1024.0f)
+        s = 1024.0f; //  Bigger values would give a too high number of segments in the circle markers.
+
+    int step = (int) (60 / sqrt(s));
+    for (int i = 0; i < 360; i += step)
+    {
+        float degInRad = (float) (i * PI / 180);
+        glVertex3f((float) cos(degInRad) * s, (float) sin(degInRad) * s, 0.0f);
+    }
 }
 
 
-void Marker::render() const
+MarkerRepresentation::MarkerRepresentation(const MarkerRepresentation& rep) :
+    m_symbol(rep.m_symbol),
+    m_size(rep.m_size),
+    m_color(rep.m_color),
+    m_label(rep.m_label)
 {
-    float s = getSize() / 2.0f;
+}
 
-    switch (symbol)
+
+MarkerRepresentation&
+MarkerRepresentation::operator=(const MarkerRepresentation& rep)
+{
+    m_symbol = rep.m_symbol;
+    m_size = rep.m_size;
+    m_color = rep.m_color;
+    m_label = rep.m_label;
+    
+    return *this;
+}
+    
+   
+void MarkerRepresentation::setColor(Color color)
+{
+    m_color = color;
+}
+
+
+void MarkerRepresentation::setSize(float size)
+{
+    m_size = size;
+}
+
+
+void MarkerRepresentation::setLabel(const std::string& label)
+{
+    m_label = label;
+}
+
+
+/*! Render the marker symbol at the specified size. The size is
+ *  the diameter of the marker in pixels.
+ */
+void MarkerRepresentation::render(float size) const
+{
+    float s = size / 2.0f;
+
+    switch (m_symbol)
     {
     case Diamond:
         glBegin(GL_LINE_LOOP);
@@ -212,22 +259,13 @@ void Marker::render() const
 
     case Circle:
         glBegin(GL_LINE_LOOP);
-        
+        DrawCircle(s);
+        glEnd();    
+        break;
+            
     case Disk:
         glBegin(GL_POLYGON);
-
-        if (s < 1.0f)
-            s = 1.0f; //  0 and negative values are not allowed in the case of circle markers.
-        else if (s > 1024.0f)
-            s = 1024.0f; //  Bigger values would give a too high number of segments in the circle markers.
-
-        int step = (int) (60 / sqrt(s));
-        for (int i=0; i < 360; i=i+step)
-        {
-            float degInRad = (float) (i * PI / 180);
-            glVertex3f((float) cos(degInRad) * s, (float) sin(degInRad) * s, 0.0f);
-        }
-        
+        DrawCircle(s);
         glEnd();
         break;
     }
