@@ -17,6 +17,7 @@
 #include <celmath/aabox.h>
 #include <vector>
 #include <string>
+#include "gl.h"
 
 
 class RenderContext;
@@ -115,10 +116,11 @@ class Mesh
 
     enum BlendMode
     {
-        NormalBlend            = 0,
-        AdditiveBlend          = 1,
-        BlendMax               = 2,
-        InvalidBlend           = -1,
+        NormalBlend             = 0,
+        AdditiveBlend           = 1,
+        PremultipliedAlphaBlend = 2,
+        BlendMax                = 3,
+        InvalidBlend            = -1,
     };
 
     class Material
@@ -216,7 +218,7 @@ class Mesh
 
     uint32 nVertices;
     void* vertices;
-    mutable uint32 vbObject;
+    mutable GLuint vbObject;
     mutable bool vbInitialized;
 
     std::vector<PrimitiveGroup*> groups;
