@@ -20,6 +20,10 @@
 using namespace std;
 
 
+// Orbital velocity is computed by differentiation for orbits that don't
+// override velocityAtTime().
+static const double ORBITAL_VELOCITY_DIFF_DELTA = 1.0 / 1440.0;
+
 
 EllipticalOrbit::EllipticalOrbit(double _pericenterDistance,
                                  double _eccentricity,
@@ -38,6 +42,9 @@ EllipticalOrbit::EllipticalOrbit(double _pericenterDistance,
     period(_period),
     epoch(_epoch)
 {
+    orbitPlaneRotation = (Mat3d::zrotation(_ascendingNode) *
+                          Mat3d::xrotation(_inclination) *
+                          Mat3d::zrotation(_argOfPeriapsis));
 }
 
 
@@ -116,6 +123,14 @@ struct SolveKeplerLaguerreConwayHyp : public unary_function<double, double>
 typedef pair<double, double> Solution;
 
 
+Vec3d Orbit::velocityAtTime(double tdb) const
+{
+	Point3d p0 = positionAtTime(tdb);
+	Point3d p1 = positionAtTime(tdb + ORBITAL_VELOCITY_DIFF_DELTA);
+	return (p1 - p0) * (1.0 / ORBITAL_VELOCITY_DIFF_DELTA);
+}
+
+
 double EllipticalOrbit::eccentricAnomaly(double M) const
 {
     if (eccentricity == 0.0)
@@ -164,34 +179,75 @@ double EllipticalOrbit::eccentricAnomaly(double M) const
 }
 
 
+// Compute the position at the specified eccentric
+// anomaly E.
 Point3d EllipticalOrbit::positionAtE(double E) const
 {
-    double x, z;
+    double x, y;
 
     if (eccentricity < 1.0)
     {
         double a = pericenterDistance / (1.0 - eccentricity);
         x = a * (cos(E) - eccentricity);
-        z = a * sqrt(1 - square(eccentricity)) * -sin(E);
+        y = a * sqrt(1 - square(eccentricity)) * sin(E);
     }
     else if (eccentricity > 1.0)
     {
         double a = pericenterDistance / (1.0 - eccentricity);
         x = -a * (eccentricity - cosh(E));
-        z = -a * sqrt(square(eccentricity) - 1) * -sinh(E);
+        y = -a * sqrt(square(eccentricity) - 1) * sinh(E);
     }
     else
     {
         // TODO: Handle parabolic orbits
         x = 0.0;
-        z = 0.0;
+        y = 0.0;
     }
 
-    Mat3d R = (Mat3d::yrotation(ascendingNode) *
-               Mat3d::xrotation(inclination) *
-               Mat3d::yrotation(argOfPeriapsis));
+    Point3d p = orbitPlaneRotation * Point3d(x, y, 0);
 
-    return R * Point3d(x, 0, z);
+    // Convert to Celestia's internal coordinate system
+    return Point3d(p.x, p.z, -p.y);
+}
+
+
+// Compute the velocity at the specified eccentric
+// anomaly E.
+Vec3d EllipticalOrbit::velocityAtE(double E) const
+{
+    double x, y;
+
+    if (eccentricity < 1.0)
+    {
+        double a = pericenterDistance / (1.0 - eccentricity);
+        double sinE = sin(E);
+        double cosE = cos(E);
+        
+        x = -a * sinE;
+        y =  a * sqrt(1 - square(eccentricity)) * cosE;
+        
+        double meanMotion = 2.0 * PI / period;
+        double edot = meanMotion / (1 - eccentricity * cosE);
+        x *= edot;
+        y *= edot;
+    }
+    else if (eccentricity > 1.0)
+    {
+        double a = pericenterDistance / (1.0 - eccentricity);
+        x = -a * (eccentricity - cosh(E));
+        y = -a * sqrt(square(eccentricity) - 1) * sinh(E);
+    }
+    else
+    {
+        // TODO: Handle parabolic orbits
+        x = 0.0;
+        y = 0.0;
+    }
+
+    Vec3d v = orbitPlaneRotation * Vec3d(x, y, 0);
+
+    // Convert to Celestia's coordinate system
+    return Vec3d(v.x, v.z, -v.y);
 }
 
 
@@ -207,6 +263,17 @@ Point3d EllipticalOrbit::positionAtTime(double t) const
 }
 
 
+Vec3d EllipticalOrbit::velocityAtTime(double t) const
+{
+    t = t - epoch;
+    double meanMotion = 2.0 * PI / period;
+    double meanAnomaly = meanAnomalyAtEpoch + t * meanMotion;
+    double E = eccentricAnomaly(meanAnomaly);
+
+    return velocityAtE(E);
+}
+
+
 double EllipticalOrbit::getPeriod() const
 {
     return period;
@@ -260,6 +327,18 @@ void EllipticalOrbit::sample(double, double t, int nSamples,
 }
 
 
+CachingOrbit::CachingOrbit() :
+	lastTime(-1.0e30),
+	positionCacheValid(false),
+	velocityCacheValid(false)
+{
+}
+
+
+CachingOrbit::~CachingOrbit()
+{
+}
+
 
 Point3d CachingOrbit::positionAtTime(double jd) const
 {
@@ -267,11 +346,57 @@ Point3d CachingOrbit::positionAtTime(double jd) const
     {
         lastTime = jd;
         lastPosition = computePosition(jd);
+		positionCacheValid = true;
+		velocityCacheValid = false;
     }
+	else if (!positionCacheValid)
+	{
+		lastPosition = computePosition(jd);
+		positionCacheValid = true;
+	}
+
     return lastPosition;
 }
 
 
+Vec3d CachingOrbit::velocityAtTime(double jd) const
+{
+	if (jd != lastTime)
+	{
+		lastVelocity = computeVelocity(jd);
+		lastTime = jd;  // must be set *after* call to computeVelocity
+		positionCacheValid = false;
+		velocityCacheValid = true;
+	}
+	else if (!velocityCacheValid)
+	{
+		lastVelocity = computeVelocity(jd);
+		velocityCacheValid = true;
+	}
+
+	return lastVelocity;
+}
+
+
+/*! Calculate the velocity at the specified time (units are
+ *  kilometers / Julian day.) The default implementation just
+ *  differentiates the position.
+ */
+Vec3d CachingOrbit::computeVelocity(double jd) const
+{
+	// Compute the velocity by differentiating.
+	Point3d p0 = positionAtTime(jd);
+
+	// Call computePosition() instead of positionAtTime() so that we
+	// don't affect the cached value. 
+	// TODO: check the valid ranges of the orbit to make sure that
+	// jd+dt is still in range.
+	Point3d p1 = computePosition(jd + ORBITAL_VELOCITY_DIFF_DELTA);
+
+	return (p1 - p0) * (1.0 / ORBITAL_VELOCITY_DIFF_DELTA);
+}
+
+
 void CachingOrbit::sample(double start, double t, int nSamples,
                           OrbitSampleProc& proc) const
 {
@@ -335,16 +460,6 @@ static EllipticalOrbit* StateVectorToOrbit(const Point3d& position,
     double T = 2 * PI * sqrt(cube(a) / GM);
     T = T / 86400.0; // Convert from seconds to days
 
-#if 0
-    cout << "a: " << astro::kilometersToAU(a) << '\n';
-    cout << "e: " << e << '\n';
-    cout << "i: " << radToDeg(i) << '\n';
-    cout << "Om: " << radToDeg(Om) << '\n';
-    cout << "om: " << radToDeg(om) << '\n';
-    cout << "M: " << radToDeg(M) << '\n';
-    cout << "T: " << T << '\n';
-#endif
-
     return new EllipticalOrbit(a * (1 - e), e, i, Om, om, M, T, t);
 }
 
@@ -397,6 +512,17 @@ Point3d MixedOrbit::positionAtTime(double jd) const
 }
 
 
+Vec3d MixedOrbit::velocityAtTime(double jd) const
+{
+    if (jd < begin)
+        return beforeApprox->velocityAtTime(jd);
+    else if (jd < end)
+        return primary->velocityAtTime(jd);
+    else
+        return afterApprox->velocityAtTime(jd);
+}
+
+
 double MixedOrbit::getPeriod() const
 {
     return primary->getPeriod();
@@ -498,7 +624,7 @@ Point3d SynchronousOrbit::positionAtTime(double jd) const
 
 double SynchronousOrbit::getPeriod() const
 {
-    return body.getRotationModel()->getPeriod();
+    return body.getRotationModel(0.0)->getPeriod();
 }
 
 
