@@ -7,6 +7,7 @@
 // as published by the Free Software Foundation; either version 2
 // of the License, or (at your option) any later version.
 
+#include <cstring>
 #include <cstdarg>
 #include <cstdio>
 #include <celutil/utf8.h>
@@ -112,7 +113,7 @@ void Overlay::print(wchar_t c)
             if (textBlock > 0)
             {
                 glPopMatrix();
-                glTranslatef(0, -(1 + font->getHeight()), 0);
+                glTranslatef(0.0f, (float) -(1 + font->getHeight()), 0.0f);
                 glPushMatrix();
             }
             break;
@@ -142,7 +143,7 @@ void Overlay::print(char c)
             if (textBlock > 0)
             {
                 glPopMatrix();
-                glTranslatef(0, -(1 + font->getHeight()), 0);
+                glTranslatef(0.0f, (float) -(1 + font->getHeight()), 0.0f);
                 glPushMatrix();
             }
             break;
