@@ -1,6 +1,6 @@
 // parseobject.cpp
 //
-// Copyright (C) 2004-2007 Chris Laurel <claurel@gmail.com>
+// Copyright (C) 2004-2008 Chris Laurel <claurel@gmail.com>
 //
 // Functions for parsing objects common to star, solar system, and
 // deep sky catalogs.
@@ -14,7 +14,9 @@
 #include <celutil/debug.h>
 #include "parseobject.h"
 #include "customorbit.h"
+#include "customrotation.h"
 #include "spiceorbit.h"
+#include "spicerotation.h"
 #include "scriptorbit.h"
 #include "scriptrotation.h"
 #include "frame.h"
@@ -212,7 +214,133 @@ CreateSampledTrajectory(Hash* trajData, const string& path)
 }
 
 
+// Create a new FixedPosition trajectory. A FixedPosition is a property list
+// with one of the following 3-vector properties:
+//     Rectangular
+//     Planetographic
+//     Planetocentric
+// Planetographic and planetocentric coordinates are given in the order longitude,
+// latitude, altitude. Units of altitude are kilometers. Planetographic and
+// and planetocentric coordinates are only practical when the coordinate system
+// is BodyFixed.
+static Orbit*
+CreateFixedPosition(Hash* trajData, const Selection& centralObject, bool usePlanetUnits)
+{
+    Vec3d position(0.0, 0.0, 0.0);
+
+    Vec3d v(0.0, 0.0, 0.0);
+    if (trajData->getVector("Rectangular", v))
+    {       
+        if (usePlanetUnits)
+            v = v * astro::AUtoKilometers(1.0);
+        // Convert to Celestia's coordinate system
+        position = Vec3d(v.x, v.z, -v.y);
+    }
+    else if (trajData->getVector("Planetographic", v))
+    {
+        if (centralObject.getType() != Selection::Type_Body)
+        {
+            clog << "FixedPosition planetographic coordinates aren't valid for stars.\n";
+            return NULL;
+        }
+
+        // TODO: Need function to calculate planetographic coordinates
+        // TODO: Change planetocentricToCartesian so that 180 degree offset isn't required
+        position = centralObject.body()->planetocentricToCartesian(180.0 + v.x, v.y, v.z);
+    }
+    else if (trajData->getVector("Planetocentric", v))
+    {
+        if (centralObject.getType() != Selection::Type_Body)
+        {
+            clog << "FixedPosition planetocentric coordinates aren't valid for stars.\n";
+            return NULL;
+        }
+
+        // TODO: Change planetocentricToCartesian so that 180 degree offset isn't required
+        position = centralObject.body()->planetocentricToCartesian(180.0 + v.x, v.y, v.z);
+    }
+    else
+    {
+        clog << "Missing coordinates for FixedPosition\n";
+        return NULL;
+    }
+
+    return new FixedOrbit(Point3d(position.x, position.y, position.z));
+}
+
+
+// Parse a string list--either a single string or an array of strings is permitted.
+static bool
+ParseStringList(Hash* table,
+				const string& propertyName,
+				list<string>& stringList)
+{
+	Value* v = table->getValue(propertyName);
+	if (v == NULL)
+		return NULL;
+
+	// Check for a single string first.
+	if (v->getType() == Value::StringType)
+	{
+		stringList.push_back(v->getString());
+		return true;
+	}
+	else if (v->getType() == Value::ArrayType)
+	{
+		Array* array = v->getArray();
+		Array::const_iterator iter;
+
+		// Verify that all array entries are strings
+		for (iter = array->begin(); iter != array->end(); iter++)
+		{
+			if ((*iter)->getType() != Value::StringType)
+				return false;
+		}
+
+		// Add strings to stringList
+		for (iter = array->begin(); iter != array->end(); iter++)
+			 stringList.push_back((*iter)->getString());
+
+		return true;
+	}
+	else
+	{
+		return false;
+	}
+}
+
+
 #ifdef USE_SPICE
+
+/*! Create a new SPICE orbit. This is just a Celestia wrapper for a trajectory specified
+ *  in a SPICE SPK file.
+ *
+ *  SpiceOrbit
+ *  {
+ *      Kernel <string|string array>   # optional
+ *      Target <string>
+ *      Origin <string>
+ *      BoundingRadius <number>
+ *      Period <number>                # optional
+ *      Beginning <number>             # optional
+ *      Ending <number>                # optional
+ *  }
+ *
+ *  The Kernel property specifies one or more SPK files that must be loaded. Any 
+ *  already loaded kernels will also be used if they contain trajectories for
+ *  the target or origin.
+ *  Target and origin are strings that give NAIF IDs for the target and origin
+ *  objects. Either names or integer IDs are valid, but integer IDs still must
+ *  be quoted.
+ *  BoundingRadius gives a conservative estimate of the maximum distance between
+ *  the target and origin objects. It is required by Celestia for visibility
+ *  culling when rendering.
+ *  Beginning and Ending specify the valid time range of the SPICE orbit. It is
+ *  an error to specify Beginning without Ending, and vice versa. If neither is
+ *  specified, the valid range is computed from the coverage window in the SPICE
+ *  kernel pool. If the coverage window is noncontiguous, the first interval is
+ *  used.
+ */
 static SpiceOrbit*
 CreateSpiceOrbit(Hash* orbitData,
                  const string& path,
@@ -220,12 +348,18 @@ CreateSpiceOrbit(Hash* orbitData,
 {
     string targetBodyName;
     string originName;
-    string kernelFileName;
-    if (!orbitData->getString("Kernel", kernelFileName))
-    {
-        clog << "Kernel filename missing from SPICE orbit\n";
-        return NULL;
-    }
+	list<string> kernelList;
+
+	if (orbitData->getValue("Kernel") != NULL)
+	{
+		// Kernel list is optional; a SPICE orbit may rely on kernels already loaded into
+		// the kernel pool.
+		if (!ParseStringList(orbitData, "Kernel", kernelList))
+		{
+			clog << "Kernel list for SPICE orbit is neither a string nor array of strings\n";
+			return NULL;
+		}
+	}
 
     if (!orbitData->getString("Target", targetBodyName))
     {
@@ -239,20 +373,6 @@ CreateSpiceOrbit(Hash* orbitData,
         return NULL;
     }
 
-    double beginningTDBJD = 0.0;
-    if (!ParseDate(orbitData, "Beginning", beginningTDBJD))
-    {
-        clog << "Beginning date missing from SPICE orbit\n";
-        return NULL;
-    }
-
-    double endingTDBJD = 0.0;
-    if (!ParseDate(orbitData, "Ending", endingTDBJD))
-    {
-        clog << "Ending date missing from SPICE orbit\n";
-        return NULL;
-    }
-
     // A bounding radius for culling is required for SPICE orbits
     double boundingRadius = 0.0;
     if (!orbitData->getNumber("BoundingRadius", boundingRadius))
@@ -273,14 +393,57 @@ CreateSpiceOrbit(Hash* orbitData,
         period = period * 365.25;
     }
 
-    SpiceOrbit* orbit = new SpiceOrbit(kernelFileName,
-                                       targetBodyName,
-                                       originName,
-                                       period,
-                                       boundingRadius,
-                                       beginningTDBJD,
-                                       endingTDBJD);
-    if (!orbit->init(path))
+	// Either a complete time interval must be specified with Beginning/Ending, or
+	// else neither field can be present.
+	Value* beginningDate = orbitData->getValue("Beginning");
+	Value* endingDate = orbitData->getValue("Ending");
+	if (beginningDate != NULL && endingDate == NULL)
+	{
+		clog << "Beginning specified for SPICE orbit, but ending is missing.\n";
+		return NULL;
+	}
+
+	if (endingDate != NULL && beginningDate == NULL)
+	{
+		clog << "Ending specified for SPICE orbit, but beginning is missing.\n";
+		return NULL;
+	}
+
+	SpiceOrbit* orbit = NULL;
+	if (beginningDate != NULL && endingDate != NULL)
+	{
+		double beginningTDBJD = 0.0;
+		if (!ParseDate(orbitData, "Beginning", beginningTDBJD))
+		{
+			clog << "Invalid beginning date specified for SPICE orbit.\n";
+			return NULL;
+		}
+
+		double endingTDBJD = 0.0;
+		if (!ParseDate(orbitData, "Ending", endingTDBJD))
+		{
+			clog << "Invalid ending date specified for SPICE orbit.\n";
+			return NULL;
+		}
+	
+		orbit = new SpiceOrbit(targetBodyName,
+							   originName,
+							   period,
+							   boundingRadius,
+							   beginningTDBJD,
+							   endingTDBJD);
+	}
+	else
+	{
+		// No time interval given; we'll use whatever coverage window is given
+		// in the SPICE kernel.
+		orbit = new SpiceOrbit(targetBodyName,
+							   originName,
+							   period,
+							   boundingRadius);
+	}
+
+    if (!orbit->init(path, &kernelList))
     {
         // Error using SPICE library; destroy the orbit; hopefully a
         // fallback is defined in the SSC file.
@@ -290,12 +453,132 @@ CreateSpiceOrbit(Hash* orbitData,
 
     return orbit;
 }
+
+
+/*! Create a new rotation model based on a SPICE frame.
+ *
+ *  SpiceRotation
+ *  {
+ *      Kernel <string|string array>   # optional
+ *      Frame <string>
+ *      BaseFrame <string>             # optional (defaults to ecliptic)
+ *      Period <number>                # optional (units are hours)
+ *      Beginning <number>             # optional
+ *      Ending <number>                # optional
+ *  }
+ *
+ *  The Kernel property specifies one or more SPICE kernel files that must be
+ *  loaded in order for the frame to be defined over the required range. Any 
+ *  already loaded kernels will be used if they contain information relevant
+ *  for defining the frame.
+ *  Frame and base name are strings that give SPICE names for the frames. The
+ *  orientation of the SpiceRotation is the orientation of the frame relative to
+ *  the base frame. By default, the base frame is eclipj2000.
+ *  Beginning and Ending specify the valid time range of the SPICE rotation.
+ *  If the Beginning and Ending are omitted, the rotation model is assumed to
+ *  be valid at any time. It is an error to specify Beginning without Ending,
+ *  and vice versa.
+ *  Period specifies the principal rotation period; it defaults to 0 indicating
+ *  that the rotation is aperiodic. It is not essential to provide the rotation
+ *  period; it is only used by Celestia for displaying object information such
+ *  as sidereal day length.
+ */
+static SpiceRotation*
+CreateSpiceRotation(Hash* rotationData,
+                    const string& path)
+{
+    string frameName;
+    string baseFrameName = "eclipj2000";
+	list<string> kernelList;
+
+	if (rotationData->getValue("Kernel") != NULL)
+	{
+		// Kernel list is optional; a SPICE rotation may rely on kernels already loaded into
+		// the kernel pool.
+		if (!ParseStringList(rotationData, "Kernel", kernelList))
+		{
+			clog << "Kernel list for SPICE rotation is neither a string nor array of strings\n";
+			return NULL;
+		}
+	}
+
+    if (!rotationData->getString("Frame", frameName))
+    {
+        clog << "Frame name missing from SPICE rotation\n";
+        return NULL;
+    }
+
+    rotationData->getString("BaseFrame", baseFrameName);
+
+    // The period of the rotation may be specified if appropriate; a value
+    // of zero for the period (the default), means that the rotation will
+    // be considered aperiodic.
+    double period = 0.0;
+    rotationData->getNumber("Period", period);
+    period = period / 24.0;
+
+	// Either a complete time interval must be specified with Beginning/Ending, or
+	// else neither field can be present.
+	Value* beginningDate = rotationData->getValue("Beginning");
+	Value* endingDate = rotationData->getValue("Ending");
+	if (beginningDate != NULL && endingDate == NULL)
+	{
+		clog << "Beginning specified for SPICE rotation, but ending is missing.\n";
+		return NULL;
+	}
+
+	if (endingDate != NULL && beginningDate == NULL)
+	{
+		clog << "Ending specified for SPICE rotation, but beginning is missing.\n";
+		return NULL;
+	}
+
+	SpiceRotation* rotation = NULL;
+	if (beginningDate != NULL && endingDate != NULL)
+	{
+		double beginningTDBJD = 0.0;
+		if (!ParseDate(rotationData, "Beginning", beginningTDBJD))
+		{
+			clog << "Invalid beginning date specified for SPICE rotation.\n";
+			return NULL;
+		}
+
+		double endingTDBJD = 0.0;
+		if (!ParseDate(rotationData, "Ending", endingTDBJD))
+		{
+			clog << "Invalid ending date specified for SPICE rotation.\n";
+			return NULL;
+		}
+	
+		rotation = new SpiceRotation(frameName,
+				  			         baseFrameName,
+							         period,
+							         beginningTDBJD,
+							         endingTDBJD);
+	}
+	else
+	{
+		// No time interval given; rotation is valid at any time.
+		rotation = new SpiceRotation(frameName,
+                                     baseFrameName,
+                                     period);
+	}
+
+    if (!rotation->init(path, &kernelList))
+    {
+        // Error using SPICE library; destroy the rotation.
+        delete rotation;
+        rotation = NULL;
+    }
+
+    return rotation;
+}
 #endif
 
 
 static ScriptedOrbit*
 CreateScriptedOrbit(Hash* orbitData,
-                    const string& /*path*/)
+                    const string& path)
 {
 #if !defined(CELX)
     clog << "ScriptedOrbit not usable without scripting support.\n";
@@ -314,6 +597,10 @@ CreateScriptedOrbit(Hash* orbitData,
     string moduleName;
     orbitData->getString("Module", moduleName);
 
+    string* pathCopy = new string(path);
+    Value* pathValue = new Value(*pathCopy);
+    orbitData->addValue("AddonPath", *pathValue);
+
     ScriptedOrbit* scriptedOrbit = new ScriptedOrbit();
     if (scriptedOrbit != NULL)
     {
@@ -330,7 +617,7 @@ CreateScriptedOrbit(Hash* orbitData,
 
 
 Orbit*
-CreateOrbit(PlanetarySystem* system,
+CreateOrbit(const Selection& centralObject,
             Hash* planetData,
             const string& path,
             bool usePlanetUnits)
@@ -440,33 +727,56 @@ CreateOrbit(PlanetarySystem* system,
     }
 
     // Create an 'orbit' that places the object at a fixed point in its
-    // reference frame.
-    Vec3d fixedPosition(0.0, 0.0, 0.0);
-    if (planetData->getVector("FixedPosition", fixedPosition))
+    // reference frame. There are two forms for FixedPosition: a simple
+    // form with an 3-vector value, and complex form with a properlist
+    // value. The simple form:
+    //
+    // FixedPosition [ x y z ]
+    //
+    // is a shorthand for:
+    //
+    // FixedPosition { Rectangular [ x y z ] }
+    //
+    // In addition to Rectangular, other coordinate types for fixed position are
+    // Planetographic and Planetocentric.
+    Value* fixedPositionValue = planetData->getValue("FixedPosition");
+    if (fixedPositionValue != NULL)
     {
-        // Convert to Celestia's coordinate system
-        fixedPosition = Vec3d(fixedPosition.x,
-                              fixedPosition.z,
-                              -fixedPosition.y);
+        Vec3d fixedPosition(0.0, 0.0, 0.0);
+        if (planetData->getVector("FixedPosition", fixedPosition))
+        {
+            // Convert to Celestia's coordinate system
+            fixedPosition = Vec3d(fixedPosition.x,
+                                  fixedPosition.z,
+                                  -fixedPosition.y);
 
-        if (usePlanetUnits)
-            fixedPosition = fixedPosition * astro::AUtoKilometers(1.0);
+            if (usePlanetUnits)
+                fixedPosition = fixedPosition * astro::AUtoKilometers(1.0);
 
-        return new FixedOrbit(Point3d(0.0, 0.0, 0.0) + fixedPosition);
+            return new FixedOrbit(Point3d(0.0, 0.0, 0.0) + fixedPosition);
+        }
+        else if (fixedPositionValue->getType() == Value::HashType)
+        {
+            return CreateFixedPosition(fixedPositionValue->getHash(), centralObject, usePlanetUnits);
+        }
+        else
+        {
+            clog << "Object has incorrect FixedPosition syntax.\n";
+        }
     }
 
-    // LongLat will make an object fixed relative to the surface of its parent
+    // LongLat will make an object fixed relative to the surface of its center
     // object. This is done by creating an orbit with a period equal to the
     // rotation rate of the parent object. A body-fixed reference frame is a
     // much better way to accomplish this.
     Vec3d longlat(0.0, 0.0, 0.0);
-    if (planetData->getVector("LongLat", longlat) && system != NULL)
+    if (planetData->getVector("LongLat", longlat))
     {
-        Body* parent = system->getPrimaryBody();
-        if (parent != NULL)
+        Body* centralBody = centralObject.body();
+        if (centralBody != NULL)
         {
-            Vec3d pos = parent->planetocentricToCartesian(longlat.x, longlat.y, longlat.z);
-            return new SynchronousOrbit(*parent, Point3d(pos.x, pos.y, pos.z));
+            Vec3d pos = centralBody->planetocentricToCartesian(longlat.x, longlat.y, longlat.z);
+            return new SynchronousOrbit(*centralBody, Point3d(pos.x, pos.y, pos.z));
         }
         else
         {
@@ -572,6 +882,35 @@ CreateFixedRotationModel(Hash* rotationData)
 }
 
 
+static ConstantOrientation*
+CreateFixedAttitudeRotationModel(Hash* rotationData)
+{
+    double heading = 0.0;
+    if (rotationData->getNumber("Heading", heading))
+    {
+        heading = degToRad(heading);
+    }
+    
+    double tilt = 0.0;
+    if (rotationData->getNumber("Tilt", tilt))
+    {
+        tilt = degToRad(tilt);
+    }
+    
+    double roll = 0.0;
+    if (rotationData->getNumber("Roll", roll))
+    {
+        roll = degToRad(roll);
+    }
+    
+    Quatd q = Quatd::yrotation(-PI - heading) *
+              Quatd::xrotation(-tilt) *
+              Quatd::zrotation(-roll);
+    
+    return new ConstantOrientation(q);
+}
+
+
 static RotationModel*
 CreatePrecessingRotationModel(Hash* rotationData,
                               double syncRotationPeriod)
@@ -636,7 +975,7 @@ CreatePrecessingRotationModel(Hash* rotationData,
 
 static ScriptedRotation*
 CreateScriptedRotation(Hash* rotationData,
-                       const string& /*path*/)
+                       const string& path)
 {
 #if !defined(CELX)
     clog << "ScriptedRotation not usable without scripting support.\n";
@@ -655,6 +994,10 @@ CreateScriptedRotation(Hash* rotationData,
     string moduleName;
     rotationData->getString("Module", moduleName);
 
+    string* pathCopy = new string(path);
+    Value* pathValue = new Value(*pathCopy);
+    rotationData->addValue("AddonPath", *pathValue);
+
     ScriptedRotation* scriptedRotation = new ScriptedRotation();
     if (scriptedRotation != NULL)
     {
@@ -691,10 +1034,9 @@ CreateRotationModel(Hash* planetData,
     //   legacy rotation parameters
 
     string customRotationModelName;
-    if (planetData->getString("CustomRotationModel", customRotationModelName))
+    if (planetData->getString("CustomRotation", customRotationModelName))
     {
-        //rotationModel = GetCustomRotationModel(customRotationModelName);
-        rotationModel = NULL;
+        rotationModel = GetCustomRotationModel(customRotationModelName);
         if (rotationModel != NULL)
         {
             return rotationModel;
@@ -704,7 +1046,25 @@ CreateRotationModel(Hash* planetData,
     }
 
 #ifdef USE_SPICE
-    // TODO: implement SPICE frame based rotations
+    Value* spiceRotationDataValue = planetData->getValue("SpiceRotation");
+    if (spiceRotationDataValue != NULL)
+    {
+        if (spiceRotationDataValue->getType() != Value::HashType)
+        {
+            clog << "Object has incorrect spice rotation syntax.\n";
+            return NULL;
+        }
+        else
+        {
+            rotationModel = CreateSpiceRotation(spiceRotationDataValue->getHash(), path);
+            if (rotationModel != NULL)
+            {
+                return rotationModel;
+            }
+            clog << "Bad spice rotation model\n";
+            DPRINTF(0, "Could not load SPICE rotation model\n");
+        }
+    }
 #endif
 
     Value* scriptedRotationValue = planetData->getValue("ScriptedRotation");
@@ -760,7 +1120,7 @@ CreateRotationModel(Hash* planetData,
     {
         if (uniformRotationValue->getType() != Value::HashType)
         {
-            clog << "Object has incorrect uniform rotation syntax.\n";
+            clog << "Object has incorrect UniformRotation syntax.\n";
             return NULL;
         }
         else
@@ -775,7 +1135,7 @@ CreateRotationModel(Hash* planetData,
     {
         if (fixedRotationValue->getType() != Value::HashType)
         {
-            clog << "Object has incorrect fixed rotation syntax.\n";
+            clog << "Object has incorrect FixedRotation syntax.\n";
             return NULL;
         }
         else
@@ -783,6 +1143,20 @@ CreateRotationModel(Hash* planetData,
             return CreateFixedRotationModel(fixedRotationValue->getHash());
         }
     }
+    
+    Value* fixedAttitudeValue = planetData->getValue("FixedAttitude");
+    if (fixedAttitudeValue != NULL)
+    {
+        if (fixedAttitudeValue->getType() != Value::HashType)
+        {
+            clog << "Object has incorrect FixedAttitude syntax.\n";
+            return NULL;
+        }
+        else
+        {
+            return CreateFixedAttitudeRotationModel(fixedAttitudeValue->getHash());
+        }
+    }
 
     // For backward compatibility we need to support rotation parameters
     // that appear in the main block of the object definition.
@@ -889,13 +1263,14 @@ RotationModel* CreateDefaultRotationModel(double syncRotationPeriod)
 // Get the center object of a frame definition. Return an empty selection
 // if it's missing or refers to an object that doesn't exist.
 static Selection
-getFrameCenter(const Universe& universe, Hash* frameData)
+getFrameCenter(const Universe& universe, Hash* frameData, const Selection& defaultCenter)
 {
     string centerName;
     if (!frameData->getString("Center", centerName))
     {
-        cerr << "No center specified for reference frame.\n";
-        return Selection();
+        if (defaultCenter.empty())
+            cerr << "No center specified for reference frame.\n";
+        return defaultCenter;
     }
 
     Selection centerObject = universe.findPath(centerName, NULL, 0);
@@ -915,9 +1290,10 @@ getFrameCenter(const Universe& universe, Hash* frameData)
 
 static BodyFixedFrame*
 CreateBodyFixedFrame(const Universe& universe,
-                     Hash* frameData)
+                     Hash* frameData,
+                     const Selection& defaultCenter)
 {
-    Selection center = getFrameCenter(universe, frameData);
+    Selection center = getFrameCenter(universe, frameData, defaultCenter);
     if (center.empty())
         return NULL;
     else
@@ -927,9 +1303,10 @@ CreateBodyFixedFrame(const Universe& universe,
 
 static BodyMeanEquatorFrame*
 CreateMeanEquatorFrame(const Universe& universe,
-                       Hash* frameData)
+                       Hash* frameData,
+                       const Selection& defaultCenter)
 {
-    Selection center = getFrameCenter(universe, frameData);
+    Selection center = getFrameCenter(universe, frameData, defaultCenter);
     if (center.empty())
         return NULL;
 
@@ -1144,7 +1521,7 @@ CreateFrameVector(const Universe& universe,
         Value* frameValue = constVecData->getValue("Frame");
         if (frameValue != NULL)
         {
-            f = CreateReferenceFrame(universe, frameValue);
+            f = CreateReferenceFrame(universe, frameValue, center, NULL);
             if (f == NULL)
                 return NULL;
         }
@@ -1161,9 +1538,10 @@ CreateFrameVector(const Universe& universe,
 
 static TwoVectorFrame*
 CreateTwoVectorFrame(const Universe& universe,
-                     Hash* frameData)
+                     Hash* frameData,
+                     const Selection& defaultCenter)
 {
-    Selection center = getFrameCenter(universe, frameData);
+    Selection center = getFrameCenter(universe, frameData, defaultCenter);
     if (center.empty())
         return NULL;
 
@@ -1237,9 +1615,11 @@ CreateTwoVectorFrame(const Universe& universe,
 
 static J2000EclipticFrame*
 CreateJ2000EclipticFrame(const Universe& universe,
-                         Hash* frameData)
+                         Hash* frameData,
+                         const Selection& defaultCenter)
 {
-    Selection center = getFrameCenter(universe, frameData);
+    Selection center = getFrameCenter(universe, frameData, defaultCenter);
+    
     if (center.empty())
         return NULL;
     else
@@ -1249,9 +1629,11 @@ CreateJ2000EclipticFrame(const Universe& universe,
 
 static J2000EquatorFrame*
 CreateJ2000EquatorFrame(const Universe& universe,
-                        Hash* frameData)
+                        Hash* frameData,
+                        const Selection& defaultCenter)
 {
-    Selection center = getFrameCenter(universe, frameData);
+    Selection center = getFrameCenter(universe, frameData, defaultCenter);
+    
     if (center.empty())
         return NULL;
     else
@@ -1259,8 +1641,145 @@ CreateJ2000EquatorFrame(const Universe& universe,
 }
 
 
+/* Helper function for CreateTopocentricFrame().
+ * Creates a two-vector frame with the specified center, target, and observer.
+ */
+TwoVectorFrame*
+CreateTopocentricFrame(const Selection& center,
+                       const Selection& target,
+                       const Selection& observer)
+{
+    BodyMeanEquatorFrame* eqFrame = new BodyMeanEquatorFrame(target, target);
+    FrameVector north = FrameVector::createConstantVector(Vec3d(0.0, 1.0, 0.0), eqFrame);
+    FrameVector up = FrameVector::createRelativePositionVector(observer, target);
+    
+    return new TwoVectorFrame(center, up, -2, north, -3);    
+}
+
+
+/* Create a new Topocentric frame. The topocentric frame is designed to make it easy
+ * to place objects on the surface of a planet or moon. The z-axis will point toward
+ * the observer's zenith (which here is the direction away from the center of the
+ * planet.) The x-axis will point in the local north direction. The equivalent
+ * two-vector frame is:
+ *
+ * TwoVector
+ * {
+ *    Center <center>
+ *    Primary   
+ *    {
+ *       Axis "z"
+ *       RelativePosition { Target <target> Observer <observer> }
+ *    }
+ *    Secondary   
+ *    {
+ *       Axis "x"
+ *       ConstantVector   
+ *       {
+ *          Vector [ 0 0 1]
+ *          Frame { BodyFixed { Center <target> } }
+ *       }
+ *    }
+ * }
+ *
+ * Typically, the topocentric frame is used as a BodyFrame to orient an
+ * object on the surface of a planet. In this situation, the observer is
+ * object itself and the target object is the planet. In fact, these are
+ * the defaults: when no target, observer, or center is specified, the
+ * observer and center are both 'self' and the target is the parent
+ * object. Thus, for a Mars rover, using a topocentric frame is as simple
+ * as:
+ *
+ * "Rover" "Sol/Mars"
+ * {
+ *     BodyFrame { Topocentric { } }
+ *     ...
+ * }
+ */
+static TwoVectorFrame*
+CreateTopocentricFrame(const Universe& universe,
+                       Hash* frameData,
+                       const Selection& defaultTarget,
+                       const Selection& defaultObserver)
+{
+    Selection target;
+    Selection observer;
+    Selection center;
+
+    string centerName;
+    if (frameData->getString("Center", centerName))
+    {
+        // If a center is provided, the default observer is the center and
+        // the default target is the center's parent. This gives sensible results
+        // when a topocentric frame is used as an orbit frame.
+        center = universe.findPath(centerName, NULL, 0);
+        if (center.empty())
+        {
+            cerr << "Center object '" << centerName << "' for topocentric frame not found.\n";
+            return NULL;
+       }
+
+       observer = center;
+       target = center.parent();
+    }  
+    else
+    {
+        // When no center is provided, use the default observer as the center. This
+        // is typical when a topocentric frame is the body frame. The default observer
+        // is usually the object itself.
+        target = defaultTarget;
+        observer = defaultObserver;
+        center = defaultObserver;
+    }
+
+    string targetName;
+    if (!frameData->getString("Target", targetName))
+    {
+        if (target.empty())
+        {
+            cerr << "No target specified for topocentric frame.\n";
+            return NULL;
+        }
+    }
+    else
+    {
+        target = universe.findPath(targetName, NULL, 0);
+        if (target.empty())
+        {
+            cerr << "Target object '" << targetName << "' for topocentric frame not found.\n";
+            return NULL;
+        }
+
+        // Should verify that center object is a star or planet, and
+        // that it is a member of the same star system as the body in which
+        // the frame will be used.
+    }
+
+    string observerName;
+    if (!frameData->getString("Observer", observerName))
+    {
+        if (observer.empty())
+        {
+            cerr << "No observer specified for topocentric frame.\n";
+            return NULL;
+        }
+    }
+    else
+    {
+        observer = universe.findPath(observerName, NULL, 0);
+        if (observer.empty())
+        {
+            cerr << "Observer object '" << observerName << "' for topocentric frame not found.\n";
+            return NULL;
+        }
+    }
+
+    return CreateTopocentricFrame(center, target, observer);
+}
+
+
 static ReferenceFrame*
-CreateComplexFrame(const Universe& universe, Hash* frameData)
+CreateComplexFrame(const Universe& universe, Hash* frameData, const Selection& defaultCenter, Body* defaultObserver)
 {
     Value* value = frameData->getValue("BodyFixed");
     if (value != NULL)
@@ -1272,7 +1791,7 @@ CreateComplexFrame(const Universe& universe, Hash* frameData)
         }
         else
         {
-            return CreateBodyFixedFrame(universe, value->getHash());
+            return CreateBodyFixedFrame(universe, value->getHash(), defaultCenter);
         }
     }
 
@@ -1286,7 +1805,7 @@ CreateComplexFrame(const Universe& universe, Hash* frameData)
         }
         else
         {
-            return CreateMeanEquatorFrame(universe, value->getHash());
+            return CreateMeanEquatorFrame(universe, value->getHash(), defaultCenter);
         }
     }
 
@@ -1300,7 +1819,21 @@ CreateComplexFrame(const Universe& universe, Hash* frameData)
         }
         else
         {
-            return CreateTwoVectorFrame(universe, value->getHash());
+            return CreateTwoVectorFrame(universe, value->getHash(), defaultCenter);
+        }
+    }
+
+    value = frameData->getValue("Topocentric");
+    if (value != NULL)
+    {
+        if (value->getType() != Value::HashType)
+        {
+            clog << "Object has incorrect topocentric frame syntax.\n";
+            return NULL;
+        }
+        else
+        {
+            return CreateTopocentricFrame(universe, value->getHash(), defaultCenter, Selection(defaultObserver));
         }
     }
 
@@ -1314,7 +1847,7 @@ CreateComplexFrame(const Universe& universe, Hash* frameData)
         }
         else
         {
-            return CreateJ2000EclipticFrame(universe, value->getHash());
+            return CreateJ2000EclipticFrame(universe, value->getHash(), defaultCenter);
         }
     }
 
@@ -1328,7 +1861,7 @@ CreateComplexFrame(const Universe& universe, Hash* frameData)
         }
         else
         {
-            return CreateJ2000EquatorFrame(universe, value->getHash());
+            return CreateJ2000EquatorFrame(universe, value->getHash(), defaultCenter);
         }
     }
 
@@ -1339,16 +1872,19 @@ CreateComplexFrame(const Universe& universe, Hash* frameData)
 
 
 ReferenceFrame* CreateReferenceFrame(const Universe& universe,
-                                     Value* frameValue)
+                                     Value* frameValue,
+                                     const Selection& defaultCenter,
+                                     Body* defaultObserver)
 {
     if (frameValue->getType() == Value::StringType)
     {
         // TODO: handle named frames
+        clog << "Invalid syntax for frame definition.\n";
         return NULL;
     }
     else if (frameValue->getType() == Value::HashType)
     {
-        return CreateComplexFrame(universe, frameValue->getHash());
+        return CreateComplexFrame(universe, frameValue->getHash(), defaultCenter, defaultObserver);
     }
     else
     {
