@@ -144,7 +144,8 @@ void renderSphere_GLSL(const RenderInfo& ri,
         if (renderFlags & Renderer::ShowAtmospheres)
         {
             // Only use new atmosphere code in OpenGL 2.0 path when new style parameters are defined.
-            if (atmosphere->mieScaleHeight > 0.0f)
+            // ... but don't show atmospheres when there are no light sources.
+            if (atmosphere->mieScaleHeight > 0.0f && shadprop.nLights > 0)
                 shadprop.texUsage |= ShaderProperties::Scattering;
         }
 
@@ -180,7 +181,7 @@ void renderSphere_GLSL(const RenderInfo& ri,
                 }
             }
 
-            if (cloudTex != NULL && allowCloudShadows)
+            if (cloudTex != NULL && allowCloudShadows && atmosphere->cloudShadowDepth > 0.0f)
             {
                 shadprop.texUsage |= ShaderProperties::CloudShadowTexture;
                 textures[nTextures++] = cloudTex;
@@ -212,7 +213,11 @@ void renderSphere_GLSL(const RenderInfo& ri,
 
     prog->use();
 
+#ifdef USE_HDR
+    prog->setLightParameters(ls, ri.color, ri.specularColor, Color::Black, ri.nightLightScale);
+#else
     prog->setLightParameters(ls, ri.color, ri.specularColor, Color::Black);
+#endif
 
     prog->eyePosition = ls.eyePos_obj;
     prog->shininess = ri.specularPower;
@@ -254,32 +259,37 @@ void renderSphere_GLSL(const RenderInfo& ri,
 }
 
 
-// Render a mesh object
-void renderModel_GLSL(Model* model,
-                      const RenderInfo& ri,
-                      ResourceHandle texOverride,
-                      const LightingState& ls,
-                      const Atmosphere* atmosphere,
-                      float radius,
-                      int renderFlags,
-                      const Mat4f& planetMat)
+/*! Render a mesh object
+ *  Parameters:
+ *    tsec : animation clock time in seconds
+ */
+void renderGeometry_GLSL(Geometry* geometry,
+                         const RenderInfo& ri,
+                         ResourceHandle texOverride,
+                         const LightingState& ls,
+                         const Atmosphere* atmosphere,
+                         float geometryScale,
+                         int renderFlags,
+                         const Mat4f& planetMat,
+                         double tsec)
 {
     glDisable(GL_LIGHTING);
 
-    GLSL_RenderContext rc(ls, radius, planetMat);
+    GLSL_RenderContext rc(ls, geometryScale, planetMat);
 
     if (renderFlags & Renderer::ShowAtmospheres)
     {
         rc.setAtmosphere(atmosphere);
     }
 
+    rc.setCameraOrientation(ri.orientation);
     rc.setPointScale(ri.pointScale);
 
     // Handle extended material attributes (per model only, not per submesh)
     rc.setLunarLambert(ri.lunarLambert);
 
     // Handle material override; a texture specified in an ssc file will
-    // override all materials specified in the model file.
+    // override all materials specified in the geometry file.
     if (texOverride != InvalidResource)
     {
         Mesh::Material m;
@@ -287,27 +297,34 @@ void renderModel_GLSL(Model* model,
         m.specular = ri.specularColor;
         m.specularPower = ri.specularPower;
         m.maps[Mesh::DiffuseMap] = texOverride;
-        rc.makeCurrent(m);
+        rc.setMaterial(&m);
         rc.lock();
+        geometry->render(rc, tsec);
+    }
+    else
+    {
+        geometry->render(rc, tsec);
     }
-
-    model->render(rc);
 
     glx::glUseProgramObjectARB(0);
 }
 
 
-// Render a mesh object unlit
-void renderModel_GLSL_Unlit(Model* model,
-                            const RenderInfo& ri,
-                            ResourceHandle texOverride,
-                            float radius,
-                            int renderFlags,
-                            const Mat4f& planetMat)
+/*! Render a mesh object without lighting.
+ *  Parameters:
+ *    tsec : animation clock time in seconds
+ */
+void renderGeometry_GLSL_Unlit(Geometry* geometry,
+                               const RenderInfo& ri,
+                               ResourceHandle texOverride,
+                               float geometryScale,
+                               int /* renderFlags */,
+                               const Mat4f& /* planetMat */,
+                               double tsec)
 {
     glDisable(GL_LIGHTING);
 
-    GLSLUnlit_RenderContext rc(radius);
+    GLSLUnlit_RenderContext rc(geometryScale);
 
     rc.setPointScale(ri.pointScale);
 
@@ -320,11 +337,14 @@ void renderModel_GLSL_Unlit(Model* model,
         m.specular = ri.specularColor;
         m.specularPower = ri.specularPower;
         m.maps[Mesh::DiffuseMap] = texOverride;
-        rc.makeCurrent(m);
+        rc.setMaterial(&m);
         rc.lock();
+        geometry->render(rc, tsec);
+    }
+    else
+    {
+        geometry->render(rc, tsec);
     }
-
-    model->render(rc);
 
     glx::glUseProgramObjectARB(0);
 }
@@ -395,7 +415,8 @@ void renderClouds_GLSL(const RenderInfo& ri,
         if (renderFlags & Renderer::ShowAtmospheres)
         {
             // Only use new atmosphere code in OpenGL 2.0 path when new style parameters are defined.
-            if (atmosphere->mieScaleHeight > 0.0f)
+            // ... but don't show atmospheres when there are no light sources.
+            if (atmosphere->mieScaleHeight > 0.0f && shadprop.nLights > 0)
                 shadprop.texUsage |= ShaderProperties::Scattering;
         }
     }
@@ -468,7 +489,11 @@ renderAtmosphere_GLSL(const RenderInfo& ri,
                       const Frustum& frustum,
                       const GLContext& context)
 {
-    /*unsigned int nTextures = 0;   Unused*/
+    // Currently, we just skip rendering an atmosphere when there are no
+    // light sources, even though the atmosphere would still the light
+    // of planets and stars behind it.
+    if (ls.nLights == 0)
+        return;
 
     glDisable(GL_LIGHTING);
 
@@ -635,17 +660,21 @@ void renderRings_GLSL(RingSystem& rings,
         Vec4f texGenS(sAxis.x, sAxis.y, sAxis.z, 0.5f);
         Vec4f texGenT(tAxis.x, tAxis.y, tAxis.z, 0.5f);
 
-        // r0 and r1 determine the size of the penumbra and the umbra
-        // shadow size.
+        // r0 and r1 determine the size of the planet's shadow and penumbra
+        // on the rings.
+        // TODO: A more accurate ring shadow calculation would set r1 / r0
+        // to the ratio of the apparent sizes of the planet and sun as seen
+        // from the rings. Even more realism could be attained by letting
+        // this ratio vary across the rings, though it may not make enough
+        // of a visual difference to be worth the extra effort.
         float r0 = 0.24f;
         float r1 = 0.25f;
         float bias = 1.0f / (1.0f - r1 / r0);
-        /*float scale = -bias / r0;     Unused*/
 
         prog->shadows[li][0].texGenS = texGenS;
         prog->shadows[li][0].texGenT = texGenT;
-        prog->shadows[li][0].bias = bias;
-        prog->shadows[li][0].scale = -bias / r0;
+        prog->shadows[li][0].maxDepth = 1.0f;
+        prog->shadows[li][0].falloff = bias / r0;
     }
 
     glEnable(GL_BLEND);
