@@ -7,11 +7,14 @@
 // as published by the Free Software Foundation; either version 2
 // of the License, or (at your option) any later version.
 
+#include "celutil/util.h"
 #include "gl.h"
 #include "glext.h"
 #include "shadermanager.h"
+#include <cmath>
 #include <iostream>
 #include <fstream>
+#include <sstream>
 #include <iomanip>
 #include <cstdio>
 #include <cassert>
@@ -181,12 +184,17 @@ bool operator<(const ShaderProperties& p0, const ShaderProperties& p1)
 
 ShaderManager::ShaderManager()
 {
+#if defined(_DEBUG) || defined(DEBUG)
+    // Only write to shader log file if this is a debug build
+
     if (g_shaderLogFile == NULL)
 #ifdef _WIN32
         g_shaderLogFile = new ofstream("shaders.log");
 #else
         g_shaderLogFile = new ofstream("/tmp/celestia-shaders.log");
 #endif
+
+#endif
 }
 
 
@@ -317,35 +325,31 @@ DeclareLights(const ShaderProperties& props)
     if (props.nLights == 0)
         return string("");
 
-    char lightSourceBuf[128];
-
 #ifndef USE_GLSL_STRUCTS
-    string lightSourceDecl;
+    ostringstream stream;
 
     for (unsigned int i = 0; i < props.nLights; i++)
     {
-        sprintf(lightSourceBuf,
-                "uniform vec3 light%d_direction;\n"
-                "uniform vec3 light%d_diffuse;\n"
-                "uniform vec3 light%d_specular;\n"
-                "uniform vec3 light%d_halfVector;\n",
-                i, i, i, i);
-        lightSourceDecl += string(lightSourceBuf);
+        stream << "uniform vec3 light" << i << "_direction;\n";
+        stream << "uniform vec3 light" << i << "_diffuse;\n";
+        stream << "uniform vec3 light" << i << "_specular;\n";
+        stream << "uniform vec3 light" << i << "_halfVector;\n";
+        if (props.texUsage & ShaderProperties::NightTexture)
+            stream << "uniform float light" << i << "_brightness;\n";
     }
 
-    return lightSourceDecl;
 #else
-    sprintf(lightSourceBuf,
-            "uniform struct {\n"
-            "   vec3 direction;\n"
-            "   vec3 diffuse;\n"
-            "   vec3 specular;\n"
-            "   vec3 halfVector;\n"
-            "} lights[%d];\n",
-            props.nLights);
-
-    return string(lightSourceBuf);
+    stream << "uniform struct {\n";
+    stream << "   vec3 direction;\n";
+    stream << "   vec3 diffuse;\n";
+    stream << "   vec3 specular;\n";
+    stream << "   vec3 halfVector;\n";
+    if (props.texUsage & ShaderProperties::NightTexture)
+        stream << "   float brightness;\n";
+    stream << "} lights[%d];\n";
 #endif
+
+    return stream.str();
 }
 
 
@@ -432,9 +436,14 @@ TangentSpaceTransform(const string& dst, const string& src)
 static string
 NightTextureBlend()
 {
+#if 1
     // Output the blend factor for night lights textures
     return string("totalLight = 1.0 - totalLight;\n"
                   "totalLight = totalLight * totalLight * totalLight * totalLight;\n");
+#else
+    // Alternate night light blend function; much sharper falloff near terminator.
+    return string("totalLight = clamp(10.0 * (0.1 - totalLight), 0.0, 1.0);\n");
+#endif
 }
 
 
@@ -557,7 +566,7 @@ AddDirectionalLightContrib(unsigned int i, const ShaderProperties& props)
 
     if ((props.texUsage & ShaderProperties::NightTexture) && VSComputesColorSum(props))
     {
-        source += "totalLight += NL;\n";
+        source += "totalLight += NL * " + LightProperty(i, "brightness") + ";\n";
     }
 
 
@@ -596,6 +605,19 @@ BeginLightSourceShadows(const ShaderProperties& props, unsigned int light)
 }
 
 
+// Calculate the depth of an eclipse shadow at the current fragment. Eclipse
+// shadows are circular, decreasing in depth from maxDepth at the center to
+// zero at the edge of the penumbra.
+// Eclipse shadows are approximate. They assume that the both the sun and
+// occluding body are spherical. An oblate planet is treated as if its polar
+// radius were equal to its equatorial radius. This produces quite accurate
+// eclipses for major moons around giant planets, which orbit close to the
+// equatorial plane of the planet.
+//
+// The radius of the shadow umbra and penumbra are computed accurately
+// (to the limit of the spherical approximation.) The maximum shadow depth
+// is also calculated accurately. However, the shadow falloff from from
+// the umbra to the edge of the penumbra is approximated as linear.
 static string
 Shadow(unsigned int light, unsigned int shadow)
 {
@@ -605,10 +627,22 @@ Shadow(unsigned int light, unsigned int shadow)
         IndexedParameter("shadowTexGenS", light, shadow) + ") - 0.5;\n";
     source += "shadowCenter.t = dot(vec4(position_obj, 1.0), " +
         IndexedParameter("shadowTexGenT", light, shadow) + ") - 0.5;\n";
-    source += "shadowR = clamp(dot(shadowCenter, shadowCenter) * " +
-        IndexedParameter("shadowScale", light, shadow) + " + " +
-        IndexedParameter("shadowBias", light, shadow) + ", 0.0, 1.0);\n";
-    source += "shadow *= sqrt(shadowR);\n";
+
+    // The shadow shadow consists of a circular region of constant depth (maxDepth),
+    // surrounded by a ring of linear falloff from maxDepth to zero. For a total
+    // eclipse, maxDepth is zero. In reality, the falloff function is much more complex:
+    // to calculate the exact amount of sunlight blocked, we need to calculate the
+    // a circle-circle intersection area. 
+    // (See http://mathworld.wolfram.com/Circle-CircleIntersection.html)
+    
+    // The code generated below will compute:
+    // r = 2 * sqrt(dot(shadowCenter, shadowCenter));
+    // shadowR = clamp((r - 1) * shadowFalloff, 0, shadowMaxDepth)
+    source += "shadowR = clamp((2.0 * sqrt(dot(shadowCenter, shadowCenter)) - 1.0) * " +
+        IndexedParameter("shadowFalloff", light, shadow) + ", 0.0, " +
+        IndexedParameter("shadowMaxDepth", light, shadow) + ");\n";
+    
+    source += "shadow *= 1.0 - shadowR;\n";
 
     return source;
 }
@@ -1275,6 +1309,10 @@ ShaderManager::buildFragmentShader(const ShaderProperties& props)
             {
                 source += "uniform vec3 " + FragLightProperty(i, "specColor") + ";\n";
             }
+            if (props.texUsage & ShaderProperties::NightTexture)
+            {
+                source += "uniform float " + FragLightProperty(i, "brightness") + ";\n";
+            }
         }
     }
     else if (props.lightModel == ShaderProperties::PerPixelSpecularModel)
@@ -1327,9 +1365,15 @@ ShaderManager::buildFragmentShader(const ShaderProperties& props)
         source += "varying vec3 scatterEx;\n";
     }
 
-    if ((props.texUsage & ShaderProperties::NightTexture) && VSComputesColorSum(props))
+    if ((props.texUsage & ShaderProperties::NightTexture))
     {
-        source += "varying float totalLight;\n";
+#ifdef USE_HDR
+        source += "uniform float nightLightScale;\n";
+#endif
+        if (VSComputesColorSum(props))
+        {
+            source += "varying float totalLight;\n";
+        }
     }
 
     // Declare shadow parameters
@@ -1345,9 +1389,9 @@ ShaderManager::buildFragmentShader(const ShaderProperties& props)
                 source += "uniform vec4 " +
                     IndexedParameter("shadowTexGenT", i, j) + ";\n";
                 source += "uniform float " +
-                    IndexedParameter("shadowScale", i, j) + ";\n";
+                    IndexedParameter("shadowFalloff", i, j) + ";\n";
                 source += "uniform float " +
-                    IndexedParameter("shadowBias", i, j) + ";\n";
+                    IndexedParameter("shadowMaxDepth", i, j) + ";\n";
             }
         }
     }
@@ -1447,9 +1491,10 @@ ShaderManager::buildFragmentShader(const ShaderProperties& props)
                 !VSComputesColorSum(props))
             {
                 if (i == 0)
-                    source += "float totalLight = l;\n";
+                    source += "float totalLight = ";
                 else
-                    source += "totalLight += l;\n";
+                    source += "totalLight += ";
+                source += "l * " + FragLightProperty(i, "brightness") + ";\n";
             }
 
             string illum;
@@ -1580,7 +1625,11 @@ ShaderManager::buildFragmentShader(const ShaderProperties& props)
             source += NightTextureBlend();
         }
 
+#ifdef USE_HDR
+        source += "gl_FragColor += texture2D(nightTex, " + nightTexCoord + ".st) * totalLight * nightLightScale;\n";
+#else
         source += "gl_FragColor += texture2D(nightTex, " + nightTexCoord + ".st) * totalLight;\n";
+#endif
     }
 
     if (props.texUsage & ShaderProperties::EmissiveTexture)
@@ -1707,9 +1756,9 @@ ShaderManager::buildRingsFragmentShader(const ShaderProperties& props)
                 source += "uniform vec4 " +
                     IndexedParameter("shadowTexGenT", i, j) + ";\n";
                 source += "uniform float " +
-                    IndexedParameter("shadowScale", i, j) + ";\n";
+                    IndexedParameter("shadowFalloff", i, j) + ";\n";
                 source += "uniform float " +
-                    IndexedParameter("shadowBias", i, j) + ";\n";
+                    IndexedParameter("shadowMaxDepth", i, j) + ";\n";
             }
         }
     }
@@ -1985,6 +2034,163 @@ ShaderManager::buildEmissiveFragmentShader(const ShaderProperties& props)
 }
 
 
+// Build the vertex shader used for rendering particle systems.
+GLVertexShader*
+ShaderManager::buildParticleVertexShader(const ShaderProperties& props)
+{
+    ostringstream source;
+    
+    source << CommonHeader;
+    
+    source << "// PARTICLE SHADER\n";
+    source << "// shadow count: " << props.shadowCounts << endl;
+    
+    source << DeclareLights(props);
+    
+    source << "uniform vec3 eyePosition;\n";
+
+    // TODO: scattering constants
+    
+    if (props.texUsage & ShaderProperties::PointSprite)
+    {
+        source << "uniform float pointScale;\n";
+        source << "attribute float pointSize;\n";
+    }
+    
+    // Shadow parameters
+    if (props.shadowCounts != 0)
+    {
+        source << "varying vec3 position_obj;\n";
+    }
+    
+    // Begin main() function
+    source << "\nvoid main(void)\n{\n";
+
+#define PARTICLE_PHASE_PARAMETER 0
+#if PARTICLE_PHASE_PARAMETER
+    float g = -0.4f;
+    float miePhaseAsymmetry = 1.55f * g - 0.55f * g * g * g;
+    source << "    float mieK = " << miePhaseAsymmetry << ";\n";
+
+    source << "    vec3 eyeDir = normalize(eyePosition - gl_Vertex.xyz);\n";
+    source << "    float brightness = 0.0;\n";
+    for (unsigned int i = 0; i < min(1u, props.nLights); i++)
+    {
+        source << "    {\n";
+        source << "         float cosTheta = dot(" << LightProperty(i, "direction") << ", eyeDir);\n";
+        source << "         float phMie = (1.0 - mieK * mieK) / ((1.0 - mieK * cosTheta) * (1.0 - mieK * cosTheta));\n";
+        source << "         brightness += phMie;\n";
+        source << "    }\n";
+    }
+#else
+    source << "    float brightness = 1.0;\n";
+#endif
+
+    // Optional texture coordinates (generated automatically for point
+    // sprites.)
+    if ((props.texUsage & ShaderProperties::DiffuseTexture) &&
+        !(props.texUsage & ShaderProperties::PointSprite))
+    {
+        source << "    gl_TexCoord[0].st = " << TexCoord2D(0) << ";\n";
+    }
+    
+    // Set the color. Should *always* use vertex colors for color and opacity.
+    source << "    gl_FrontColor = gl_Color * brightness;\n";
+    
+    // Optional point size
+    if ((props.texUsage & ShaderProperties::PointSprite) != 0)
+        source << PointSizeCalculation();
+    
+    source << "    gl_Position = ftransform();\n";
+    
+    source << "}\n";
+    // End of main()
+    
+    if (g_shaderLogFile != NULL)
+    {
+        *g_shaderLogFile << "Vertex shader source:\n";
+        DumpShaderSource(*g_shaderLogFile, source.str());
+        *g_shaderLogFile << endl;
+    }
+    
+    GLVertexShader* vs = NULL;
+    GLShaderStatus status = GLShaderLoader::CreateVertexShader(source.str(), &vs);
+    if (status != ShaderStatus_OK)
+        return NULL;
+    else
+        return vs;
+}
+
+
+GLFragmentShader*
+ShaderManager::buildParticleFragmentShader(const ShaderProperties& props)
+{
+    ostringstream source;
+
+    source << CommonHeader;
+    
+    if (props.texUsage & ShaderProperties::DiffuseTexture)
+    {
+        source << "uniform sampler2D diffTex;\n";
+    }
+
+    if (props.usesShadows())
+    {
+        source << "uniform vec3 ambientColor;\n";
+        for (unsigned int i = 0; i < props.nLights; i++)
+        {
+            source << "uniform vec3 " << FragLightProperty(i, "color") << ";\n";
+        }        
+    }
+    
+    // Declare shadow parameters
+    if (props.shadowCounts != 0)
+    {
+        source << "varying vec3 position_obj;\n";
+        for (unsigned int i = 0; i < props.nLights; i++)
+        {
+            for (unsigned int j = 0; j < props.getShadowCountForLight(i); j++)
+            {
+                source << "uniform vec4 " << IndexedParameter("shadowTexGenS", i, j) << ";\n";
+                source << "uniform vec4 " << IndexedParameter("shadowTexGenT", i, j) << ";\n";
+                source << "uniform float " << IndexedParameter("shadowFalloff", i, j) << ";\n";
+                source << "uniform float " << IndexedParameter("shadowMaxDepth", i, j) << ";\n";
+            }
+        }
+    }
+    
+    // Begin main()
+    source << "\nvoid main(void)\n";
+    source << "{\n";
+    
+    if (props.texUsage & ShaderProperties::DiffuseTexture)
+    {
+        source << "    gl_FragColor = gl_Color * texture2D(diffTex, gl_TexCoord[0].st);\n";
+    }
+    else
+    {
+        source << "    gl_FragColor = gl_Color;\n";
+    }
+    
+    source << "}\n";
+    // End of main()
+    
+    if (g_shaderLogFile != NULL)
+    {
+        *g_shaderLogFile << "Fragment shader source:\n";
+        DumpShaderSource(*g_shaderLogFile, source.str());
+        *g_shaderLogFile << '\n';
+    }
+    
+    GLFragmentShader* fs = NULL;
+    GLShaderStatus status = GLShaderLoader::CreateFragmentShader(source.str(), &fs);
+    if (status != ShaderStatus_OK)
+        return NULL;
+    else
+        return fs;
+}
+
+
 CelestiaGLProgram*
 ShaderManager::buildProgram(const ShaderProperties& props)
 {
@@ -2009,6 +2215,11 @@ ShaderManager::buildProgram(const ShaderProperties& props)
         vs = buildEmissiveVertexShader(props);
         fs = buildEmissiveFragmentShader(props);
     }
+    else if (props.lightModel == ShaderProperties::ParticleModel)
+    {
+        vs = buildParticleVertexShader(props);
+        fs = buildParticleFragmentShader(props);
+    }
     else
     {
         vs = buildVertexShader(props);
@@ -2115,9 +2326,13 @@ CelestiaGLProgram::initParameters()
         lights[i].diffuse    = vec3Param(LightProperty(i, "diffuse"));
         lights[i].specular   = vec3Param(LightProperty(i, "specular"));
         lights[i].halfVector = vec3Param(LightProperty(i, "halfVector"));
+        if (props.texUsage & ShaderProperties::NightTexture)
+            lights[i].brightness = floatParam(LightProperty(i, "brightness"));
 
         fragLightColor[i] = vec3Param(FragLightProperty(i, "color"));
         fragLightSpecColor[i] = vec3Param(FragLightProperty(i, "specColor"));
+        if (props.texUsage & ShaderProperties::NightTexture)
+            fragLightBrightness[i] = floatParam(FragLightProperty(i, "brightness"));
 
         for (unsigned int j = 0; j < props.getShadowCountForLight(i); j++)
         {
@@ -2125,10 +2340,10 @@ CelestiaGLProgram::initParameters()
                 vec4Param(IndexedParameter("shadowTexGenS", i, j));
             shadows[i][j].texGenT =
                 vec4Param(IndexedParameter("shadowTexGenT", i, j));
-            shadows[i][j].scale =
-                floatParam(IndexedParameter("shadowScale", i, j));
-            shadows[i][j].bias =
-                floatParam(IndexedParameter("shadowBias", i, j));
+            shadows[i][j].falloff =
+                floatParam(IndexedParameter("shadowFalloff", i, j));
+            shadows[i][j].maxDepth =
+                floatParam(IndexedParameter("shadowMaxDepth", i, j));
         }
     }
 
@@ -2144,6 +2359,9 @@ CelestiaGLProgram::initParameters()
 
     opacity      = floatParam("opacity");
     ambientColor = vec3Param("ambientColor");
+#ifdef USE_HDR
+    nightLightScale          = floatParam("nightLightScale");
+#endif
 
     if (props.texUsage & ShaderProperties::RingShadowTexture)
     {
@@ -2253,7 +2471,11 @@ void
 CelestiaGLProgram::setLightParameters(const LightingState& ls,
                                       Color materialDiffuse,
                                       Color materialSpecular,
-                                      Color materialEmissive)
+                                      Color materialEmissive
+#ifdef USE_HDR
+                                     ,float _nightLightScale
+#endif
+                                      )
 {
     unsigned int nLights = min(MaxShaderLights, ls.nLights);
 
@@ -2286,6 +2508,7 @@ CelestiaGLProgram::setLightParameters(const LightingState& ls,
                                               lightColor.y * specularColor.y,
                                               lightColor.z * specularColor.z);
             }
+            fragLightBrightness[i] = max(lightColor.x, max(lightColor.y, lightColor.z));
         }
         else
         {
@@ -2294,6 +2517,7 @@ CelestiaGLProgram::setLightParameters(const LightingState& ls,
                                       lightColor.z * diffuseColor.z);
         }
 
+        lights[i].brightness = max(lightColor.x, max(lightColor.y, lightColor.z));
         lights[i].specular = Vec3f(lightColor.x * specularColor.x,
                                    lightColor.y * specularColor.y,
                                    lightColor.z * specularColor.z);
@@ -2309,6 +2533,9 @@ CelestiaGLProgram::setLightParameters(const LightingState& ls,
                          ls.ambientColor.y * diffuseColor.y + materialEmissive.green(),
                          ls.ambientColor.z * diffuseColor.z + materialEmissive.blue());
     opacity = materialDiffuse.alpha();
+#ifdef USE_HDR
+    nightLightScale = _nightLightScale;
+#endif
 }
 
 
@@ -2332,19 +2559,12 @@ CelestiaGLProgram::setEclipseShadowParameters(const LightingState& ls,
                 EclipseShadow& shadow = ls.shadows[li]->at(i);
                 CelestiaGLProgramShadow& shadowParams = shadows[li][i];
 
-                float R2 = 0.25f;
-                float umbra = shadow.umbraRadius / shadow.penumbraRadius;
-                umbra = umbra * umbra;
-                if (umbra < 0.0001f)
-                    umbra = 0.0001f;
-                else if (umbra > 0.99f)
-                    umbra = 0.99f;
-
-                float umbraRadius = R2 * umbra;
-                float penumbraRadius = R2;
-                float shadowBias = 1.0f / (1.0f - penumbraRadius / umbraRadius);
-                shadowParams.bias = shadowBias;
-                shadowParams.scale = -shadowBias / umbraRadius;
+                // Compute shadow parameters: max depth of at the center of the shadow
+                // (always 1 if an eclipse is total) and the linear falloff
+                // rate from the center to the outer endge of the penumbra.
+                float u = shadow.umbraRadius / shadow.penumbraRadius;
+                shadowParams.falloff = -shadow.maxDepth / std::max(0.001f, 1.0f - std::fabs(u));
+                shadowParams.maxDepth = shadow.maxDepth;
 
                 // Compute the transformation to use for generating texture
                 // coordinates from the object vertices.
