@@ -46,6 +46,7 @@ class ShaderProperties
      CloudShadowTexture      =   0x80,
      CompressedNormalTexture =  0x100,
      EmissiveTexture         =  0x200,
+     VertexOpacities         =  0x800,
      VertexColors            = 0x1000,
      Scattering              = 0x2000,
      PointSprite             = 0x4000,
@@ -63,6 +64,7 @@ class ShaderProperties
      LunarLambertModel     = 6,
      ParticleDiffuseModel  = 7,
      EmissiveModel         = 8,
+     ParticleModel         = 9,
  };
  
  enum
@@ -93,14 +95,15 @@ struct CelestiaGLProgramLight
     Vec3ShaderParameter diffuse;
     Vec3ShaderParameter specular;
     Vec3ShaderParameter halfVector;
+    FloatShaderParameter brightness; // max of diffuse r, g, b
 };
 
 struct CelestiaGLProgramShadow
 {
     Vec4ShaderParameter texGenS;
     Vec4ShaderParameter texGenT;
-    FloatShaderParameter scale;
-    FloatShaderParameter bias;
+    FloatShaderParameter falloff;
+    FloatShaderParameter maxDepth;
 };
 
 class CelestiaGLProgram
@@ -114,7 +117,11 @@ class CelestiaGLProgram
     void setLightParameters(const LightingState& ls,
                             Color materialDiffuse,
                             Color materialSpecular,
-                            Color materialEmissive);
+                            Color materialEmissive
+#ifdef USE_HDR
+                           ,float nightLightScale = 1.0f
+#endif
+                            );
     void setEclipseShadowParameters(const LightingState& ls,
                                     float planetRadius,
                                     const Mat4f& planetMat);
@@ -126,10 +133,14 @@ class CelestiaGLProgram
     CelestiaGLProgramLight lights[MaxShaderLights];
     Vec3ShaderParameter fragLightColor[MaxShaderLights];
     Vec3ShaderParameter fragLightSpecColor[MaxShaderLights];
+    FloatShaderParameter fragLightBrightness[MaxShaderLights];
     Vec3ShaderParameter eyePosition;
     FloatShaderParameter shininess;
     Vec3ShaderParameter ambientColor;
     FloatShaderParameter opacity;
+#ifdef USE_HDR
+    FloatShaderParameter nightLightScale;
+#endif
 
     FloatShaderParameter ringWidth;
     FloatShaderParameter ringRadius;
@@ -217,6 +228,9 @@ class ShaderManager
     GLVertexShader* buildEmissiveVertexShader(const ShaderProperties&);
     GLFragmentShader* buildEmissiveFragmentShader(const ShaderProperties&);
 
+    GLVertexShader* buildParticleVertexShader(const ShaderProperties&);
+    GLFragmentShader* buildParticleFragmentShader(const ShaderProperties&);
+
     std::map<ShaderProperties, CelestiaGLProgram*> shaders;
 };
 
