@@ -60,6 +60,14 @@ void Simulation::render(Renderer& renderer)
                     selection);
 }
 
+void Simulation::draw(Renderer& renderer)
+{
+    renderer.draw(*activeObserver,
+                  *universe,
+                  faintestVisible,
+                  selection);
+}
+
 
 void Simulation::render(Renderer& renderer, Observer& observer)
 {
@@ -137,17 +145,7 @@ Selection Simulation::getSelection() const
 
 void Simulation::setSelection(const Selection& sel)
 {
-    if (sel != selection)
-    {
-        universe->unmarkObject(selection, 0);
-        selection = sel;
-        universe->markObject(selection,
-                             10.0f,
-                             Color(1.0f, 0.0f, 0.0f, 0.9f),
-                             Marker::Diamond,
-                             0,
-                             "");
-    }
+    selection = sel;
 }
 
 
@@ -166,7 +164,7 @@ void Simulation::setTrackedObject(const Selection& sel)
 Selection Simulation::pickObject(Vec3f pickRay, int renderFlags, float tolerance)
 {
     return universe->pick(activeObserver->getPosition(),
-                          pickRay * activeObserver->getOrientation().toMatrix4(),
+                          pickRay * activeObserver->getOrientationf().toMatrix4(),
                           activeObserver->getTime(),
                           renderFlags,
                           faintestVisible,
@@ -236,18 +234,20 @@ void Simulation::setObserverMode(Observer::ObserverMode mode)
     activeObserver->setMode(mode);
 }
 
-void Simulation::setFrame(astro::CoordinateSystem coordSys,
-                          const Selection& sel)
+void Simulation::setFrame(ObserverFrame::CoordinateSystem coordSys,
+                          const Selection& refObject,
+                          const Selection& targetObject)
 {
-    activeObserver->setFrame(FrameOfReference(coordSys, sel));
+    activeObserver->setFrame(coordSys, refObject, targetObject);
 }
 
-void Simulation::setFrame(const FrameOfReference& _frame)
+void Simulation::setFrame(ObserverFrame::CoordinateSystem coordSys,
+                          const Selection& refObject)
 {
-    activeObserver->setFrame(_frame);
+    activeObserver->setFrame(coordSys, refObject);
 }
 
-FrameOfReference Simulation::getFrame() const
+const ObserverFrame* Simulation::getFrame() const
 {
     return activeObserver->getFrame();
 }
@@ -286,7 +286,7 @@ float Simulation::getTargetSpeed()
 
 void Simulation::gotoSelection(double gotoTime,
                                Vec3f up,
-                               astro::CoordinateSystem upFrame)
+                               ObserverFrame::CoordinateSystem upFrame)
 {
     if (selection.getType() == Selection::Type_Location)
     {
@@ -303,9 +303,9 @@ void Simulation::gotoSelection(double gotoTime,
 void Simulation::gotoSelection(double gotoTime,
                                double distance,
                                Vec3f up,
-                               astro::CoordinateSystem upFrame)
+                               ObserverFrame::CoordinateSystem upCoordSys)
 {
-    activeObserver->gotoSelection(selection, gotoTime, distance, up, upFrame);
+    activeObserver->gotoSelection(selection, gotoTime, distance, up, upCoordSys);
 }
 
 void Simulation::gotoSelectionLongLat(double gotoTime,
@@ -319,10 +319,11 @@ void Simulation::gotoSelectionLongLat(double gotoTime,
 }
 
 
-void Simulation::gotoLocation(const RigidTransform& transform,
+void Simulation::gotoLocation(const UniversalCoord& position,
+                              const Quatd& orientation,
                               double duration)
 {
-    activeObserver->gotoLocation(transform, duration);
+    activeObserver->gotoLocation(position, orientation, duration);
 }
 
 
