@@ -10,6 +10,7 @@
 #include <celmath/mathlib.h>
 #include <cstring>
 #include <cassert>
+#include <cstdio>
 #include "celestia.h"
 #include "astro.h"
 #include "orbit.h"
@@ -43,6 +44,8 @@ static StarDetails*  neutronStarDetails = NULL;
 static StarDetails*  blackHoleDetails = NULL;
 static StarDetails*  barycenterDetails = NULL;
 
+static string DEFAULT_INFO_URL("");
+
 StarDetails::StarTextureSet StarDetails::starTextures;
 
 // Star temperature data from Lang's _Astrophysical Data: Planets and Stars_
@@ -437,11 +440,23 @@ StarDetails::GetNormalStarDetails(StellarClass::SpectralClass specClass,
     if (normalStarDetails[index] == NULL)
     {
         char name[16];
-        sprintf(name, "%s%s%s",
-                SpectralClassNames[specClass],
-                SubclassNames[subclass],
-                LumClassNames[lumClass]);
-
+        if ((lumClass == StellarClass::Lum_VI) &&
+            (specClass >= StellarClass::Spectral_O) && (specClass <= StellarClass::Spectral_A))
+        {
+            // Hot subdwarfs are prefixed with "sd", while cool subdwarfs use
+            // luminosity class VI, per recommendations in arXiv:0805.2567v1
+            sprintf(name, "sd%s%s",
+                    SpectralClassNames[specClass],
+                    SubclassNames[subclass]);
+        }
+        else
+        {
+            sprintf(name, "%s%s%s",
+                    SpectralClassNames[specClass],
+                    SubclassNames[subclass],
+                    LumClassNames[lumClass]);
+        }
+        
         // Use the same properties for an unknown subclass as for subclass 5
         if (subclass == StellarClass::Subclass_Unknown)
         {
@@ -742,12 +757,13 @@ StarDetails::StarDetails() :
     knowledge(0u),
     visible(true),
     texture(texture),
-    model(InvalidResource),
+    geometry(InvalidResource),
     orbit(NULL),
     orbitalRadius(0.0f),
     barycenter(NULL),
     rotationModel(NULL),
     semiAxes(1.0f, 1.0f, 1.0f),
+    infoURL(NULL),
     orbitingStars(NULL),
     isShared(true)
 {
@@ -762,23 +778,40 @@ StarDetails::StarDetails(const StarDetails& sd) :
     knowledge(sd.knowledge),
     visible(sd.visible),
     texture(sd.texture),
-    model(sd.model),
+    geometry(sd.geometry),
     orbit(sd.orbit),
     orbitalRadius(sd.orbitalRadius),
     barycenter(sd.barycenter),
     rotationModel(sd.rotationModel),
     semiAxes(sd.semiAxes),
+    infoURL(NULL),
     orbitingStars(NULL),
     isShared(false)
 {
     assert(sd.isShared);
     memcpy(spectralType, sd.spectralType, sizeof(spectralType));
+    if (sd.infoURL != NULL)
+        infoURL = new string(*sd.infoURL);
 }
 
 
 StarDetails::~StarDetails()
 {
     delete orbitingStars;
+    delete infoURL;
+}
+
+
+/*! Return the InfoURL. If the InfoURL has not been set, this method
+ *  returns an empty string.
+ */
+const std::string&
+StarDetails::getInfoURL() const
+{
+    if (infoURL != NULL)
+        return *infoURL;
+    else
+        return DEFAULT_INFO_URL;
 }
 
 
@@ -833,9 +866,9 @@ StarDetails::setTexture(const MultiResTexture& tex)
 
 
 void
-StarDetails::setModel(ResourceHandle rh)
+StarDetails::setGeometry(ResourceHandle rh)
 {
-    model = rh;
+    geometry = rh;
 }
 
 
@@ -893,6 +926,29 @@ StarDetails::setRotationModel(const RotationModel* rm)
 }
 
 
+/*! Set the InfoURL for this star.
+*/
+void
+StarDetails::setInfoURL(const string& _infoURL)
+{
+    if (_infoURL.empty())
+    {
+        // Save space in the common case--no InfoURL--by not
+        // allocating a string.
+        delete infoURL;
+        infoURL = NULL;
+    }
+    else
+    {
+        // Allocate the new string before freeing the old one, so we don't crash
+        // in the event the caller does something like:
+        // star->setInfoURL(star->getInfoURL());
+        string* oldURL = infoURL;
+        infoURL = new string(_infoURL);
+        delete oldURL;
+    }
+}
+
 
 Star::~Star()
 {
@@ -955,6 +1011,8 @@ StarDetails::addOrbitingStar(Star* star)
 }
 
 
+/*! Get the position of the star in the universal coordinate system.
+ */
 UniversalCoord
 Star::getPosition(double t) const
 {
@@ -1009,6 +1067,37 @@ Star::getOrbitBarycenterPosition(double t) const
 }
 
 
+/*! Get the velocity of the star in the universal coordinate system.
+ */
+Vec3d
+Star::getVelocity(double t) const
+{
+    const Orbit* orbit = getOrbit();
+    if (!orbit)
+    {
+		// The star doesn't have a defined orbit, so the velocity is just
+		// zero. (This will change when stellar proper motion is implemented.)
+		return Vec3d(0.0, 0.0, 0.0);
+    }
+    else
+    {
+        const Star* barycenter = getOrbitBarycenter();
+
+        if (barycenter == NULL)
+        {
+			// Star orbit is defined around a fixed point, so the total velocity
+			// is just the star's orbit velocity.
+			return orbit->velocityAtTime(t);
+        }
+        else
+        {
+			// Sum the star's orbital velocity and the velocity of the barycenter.
+            return barycenter->getVelocity(t) + orbit->velocityAtTime(t);
+        }
+    }
+}
+
+
 MultiResTexture
 Star::getTexture() const
 {
@@ -1017,9 +1106,19 @@ Star::getTexture() const
 
 
 ResourceHandle
-Star::getModel() const
+Star::getGeometry() const
 {
-    return details->getModel();
+    return details->getGeometry();
+}
+
+
+/*! Return the InfoURL. If the InfoURL has not been set, this method
+*  returns an empty string.
+*/
+const string&
+Star::getInfoURL() const
+{
+    return details->getInfoURL();
 }
 
 
@@ -1060,6 +1159,11 @@ void Star::setLuminosity(float lum)
     absMag = astro::lumToAbsMag(lum);
 }
 
+StarDetails* Star::getDetails() const
+{
+    return details;
+}
+
 void Star::setDetails(StarDetails* sd)
 {
     // TODO: delete existing details if they aren't shared
