@@ -86,6 +86,18 @@ Tokenizer::TokenType Tokenizer::nextToken()
                 sign = -1;
                 integerValue = 0;
             }
+            else if (nextChar == '+')
+            {
+                state = NumberState;
+                sign = +1;
+                integerValue = 0;
+            }
+            else if (nextChar == '.')
+            {
+                state = FractionState;
+                sign = +1;
+                integerValue = 0;
+            }
             else if (isalpha(nextChar) || nextChar == '_')
             {
                 state = NameState;
@@ -154,7 +166,7 @@ Tokenizer::TokenType Tokenizer::nextToken()
             break;
 
         case CommentState:
-            if (nextChar == '\n' || nextChar == '\r')
+            if (nextChar == '\n' || nextChar == '\r' || nextChar == char_traits<char>::eof())
                 state = StartState;
             break;
 
@@ -169,6 +181,11 @@ Tokenizer::TokenType Tokenizer::nextToken()
             {
                 state = StringEscapeState;
             }
+            else if (nextChar == char_traits<char>::eof())
+            {
+                newToken = TokenError;
+                syntaxError("Unterminated string");
+            }
             else
             {
                 state = StringState;
@@ -238,7 +255,7 @@ Tokenizer::TokenType Tokenizer::nextToken()
                 state = FractionState;
                 fractionValue = fractionValue * 10 + nextChar - (int) '0';
                 fracExp *= 10;
-            } 
+            }
             else if (nextChar == 'e' || nextChar == 'E')
             {
                 state = ExponentFirstState;
@@ -333,7 +350,10 @@ Tokenizer::TokenType Tokenizer::nextToken()
                 syntaxError("Bad Unicode escape in string");
             }
             break;
-        }
+
+        case ErrorState:    break;  // Prevent GCC4 warnings; do nothing
+
+        } // Switch
 
         if (newToken == TokenBegin)
         {
