@@ -45,7 +45,7 @@ public:
     string getNameValue();
     string getStringValue();
 
-    int getLineNumber();
+    int getLineNumber() const;
 
 private:
     enum State
@@ -61,6 +61,7 @@ private:
         StringState         = 8,
         ErrorState          = 9,
         StringEscapeState   = 10,
+        UnicodeEscapeState  = 11,
     };
 
     istream* in;
@@ -71,6 +72,9 @@ private:
     bool haveValidName;
     bool haveValidString;
 
+    unsigned int unicodeValue;
+    unsigned int unicodeEscapeDigits;
+
     bool pushedBack;
 
     int readChar();
@@ -79,6 +83,8 @@ private:
     double numberValue;
 
     string textToken;
+
+    int lineNum;
 };
 
 #endif // _TOKENIZER_H_
