@@ -588,7 +588,11 @@ static int object_getinfo(lua_State* l)
         celx.setTable("temperature", (lua_Number)star->getTemperature());
         celx.setTable("rotationPeriod", (lua_Number)star->getRotationModel()->getPeriod());
         celx.setTable("bolometricMagnitude", (lua_Number)star->getBolometricMagnitude());
-        
+
+        const Orbit* orbit = star->getOrbit();
+        if (orbit != NULL)
+            celx.setTable("orbitPeriod", orbit->getPeriod());
+
         if (star->getOrbitBarycenter() != NULL)
         {
             Selection parent((Star*)(star->getOrbitBarycenter()));
@@ -773,7 +777,7 @@ static int object_mark(lua_State* l)
         markAlpha = 1.0f;
     
     Color markColorAlpha(0.0f, 1.0f, 0.0f, 0.9f);
-    markColorAlpha = Color::Color(markColor, markAlpha);
+    markColorAlpha = Color(markColor, markAlpha);
     
     const char* markLabel = celx.safeGetString(6, WrongType, "Fifth argument to object:mark must be a string");
     if (markLabel == NULL)
