@@ -146,14 +146,14 @@ static gint TourGuideGoto(GtkWidget*, TourData* td)
 				/* Use the default distance */
 				simulation->gotoSelection(5.0,
 				                          Vec3f(0, 1, 0),
-				                          astro::ObserverLocal);
+				                          ObserverFrame::ObserverLocal);
 			}
 			else
 			{
 				simulation->gotoSelection(5.0,
 				                          td->selected->distance,
 				                          Vec3f(0, 1, 0),
-				                          astro::ObserverLocal);
+				                          ObserverFrame::ObserverLocal);
 			}
 		}
 	}
