@@ -11,6 +11,7 @@
 class Simulation;
 class CelestiaCore;
 class Star;
+class CelListViewItem;
 
 class CelestialBrowser : public CelestialBrowserBase
 {
@@ -34,6 +35,7 @@ private:
     Simulation *appSim;
     StarBrowser sbrowser;
     Selection browserSel;
+    void addPlanetarySystem(CelListViewItem* parentItem, const PlanetarySystem* system, const Point3d* parentBodyPos = NULL);
     
     QString getClassification(int c) const;
 
