@@ -24,8 +24,10 @@
 class KCelBookmarkOwner : virtual public KBookmarkOwner {
 
 public:
+    virtual ~KCelBookmarkOwner() {};
+
     virtual QString currentIcon() const { return QString::null; };
-    virtual Url currentUrl(Url::UrlType type=Url::Absolute) const { return Url(); };
+    virtual Url currentUrl(Url::UrlType /*type*/=Url::Absolute) const { return Url(); };
 };
 
 #endif
