@@ -24,8 +24,10 @@ class QSpinBox;
 class QComboBox;
 class QCheckBox;
 class KKeyChooser;
+class QLineEdit;
 
 class KdeApp;
+class astro::Date;
 
 class KdePreferencesDialog : public KDialogBase {
 Q_OBJECT
@@ -41,11 +43,14 @@ public slots:
     void setNow();
     void ltSubstract();
     void slotTimeHasChanged();
+    void slotJDHasChanged();
     void slotAmbientLightLevel(int l);
     void slotFaintestVisible(int m);
     void slotRenderPath(int);
     void slotDistanceToScreen(int);
     void slotMinFeatureSize(int);
+    void slotTextureRes(int);
+    void slotDateFormat(int);
 
 protected:
     CelestiaCore* appCore;
@@ -64,6 +69,9 @@ protected:
     int savedDistanceToScreen;
     uint32 savedLocationFilter;
     int savedMinFeatureSize;
+    bool savedVideoSync;
+    int savedTextureRes;
+    astro::Date::Format savedDateFormat;
 
     bool timeHasChanged;
 
@@ -75,6 +83,8 @@ protected:
 
     QSpinBox *dtsSpin;
 
+    QLineEdit *julianDateEdit;
+
     QComboBox *renderPathCombo;
     QLabel* renderPathLabel;
     QLabel* ambientLabel, *faintestLabel, *minFeatureSizeLabel;
