@@ -14,7 +14,7 @@
 
 #include "celestiacore.h"
 
-class ViewOptionsDialog
+class ViewOptionsDialog : public CelestiaWatcher
 {
  public:
     ViewOptionsDialog(HINSTANCE, HWND, CelestiaCore*);
@@ -22,6 +22,8 @@ class ViewOptionsDialog
     void SetControls(HWND);
     void RestoreSettings(HWND);
 
+    virtual void notifyChange(CelestiaCore*, int);
+
  public:
     CelestiaCore* appCore;
     HWND parent;
