@@ -1,14 +1,14 @@
 // frustum.h
 // 
-// Copyright (C) 2000, Chris Laurel <claurel@shatters.net>
+// Copyright (C) 2000-2008, Chris Laurel <claurel@shatters.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either version 2
 // of the License, or (at your option) any later version.
 
-#ifndef _FRUSTUM_H_
-#define _FRUSTUM_H_
+#ifndef _CELMATH_FRUSTUM_H_
+#define _CELMATH_FRUSTUM_H_
 
 #include <celmath/plane.h>
 #include <celmath/capsule.h>
@@ -57,4 +57,4 @@ Planef Frustum::getPlane(int which) const
     return planes[which];
 }
 
-#endif // _FRUSTUM_H_
+#endif // _CELMATH_FRUSTUM_H_
