@@ -24,14 +24,15 @@ public:
     inline Vector3();
     inline Vector3(const Vector3<T>&);
     inline Vector3(T, T, T);
+    inline Vector3(T*);
 
     inline T& operator[](int) const;
     inline Vector3& operator+=(const Vector3<T>&);
     inline Vector3& operator-=(const Vector3<T>&);
     inline Vector3& operator*=(T);
 
-    inline Vector3 operator-();
-    inline Vector3 operator+();
+    inline Vector3 operator-() const;
+    inline Vector3 operator+() const;
 
     inline T length() const;
     inline T lengthSquared() const;
@@ -46,6 +47,7 @@ public:
     inline Point3();
     inline Point3(const Point3&);
     inline Point3(T, T, T);
+    inline Point3(T*);
 
     inline T& operator[](int) const;
     inline Point3& operator+=(const Vector3<T>&);
@@ -93,8 +95,8 @@ template<class T> class Vector4
     inline Vector4& operator-=(const Vector4&);
     inline Vector4& operator*=(T);
 
-    inline Vector4 operator-();
-    inline Vector4 operator+();
+    inline Vector4 operator-() const;
+    inline Vector4 operator+() const;
 
     T x, y, z, w;
 };
@@ -141,6 +143,8 @@ template<class T> class Matrix3
     static Matrix3<T> xrotation(T);
     static Matrix3<T> yrotation(T);
     static Matrix3<T> zrotation(T);
+    static Matrix3<T> scaling(const Vector3<T>&);
+    static Matrix3<T> scaling(T);
 
     inline const Vector3<T>& operator[](int) const;
     inline Vector3<T> row(int) const;
@@ -189,6 +193,9 @@ template<class T> Vector3<T>::Vector3(T _x, T _y, T _z) : x(_x), y(_y), z(_z)
 {
 }
 
+template<class T> Vector3<T>::Vector3(T* v) : x(v[0]), y(v[1]), z(v[2])
+{
+}
 
 //**** Vector3 operators
 
@@ -217,12 +224,12 @@ template<class T> Vector3<T>& Vector3<T>::operator*=(T s)
     return *this;
 }
 
-template<class T> Vector3<T> Vector3<T>::operator-()
+template<class T> Vector3<T> Vector3<T>::operator-() const
 {
     return Vector3<T>(-x, -y, -z);
 }
 
-template<class T> Vector3<T> Vector3<T>::operator+()
+template<class T> Vector3<T> Vector3<T>::operator+() const
 {
     return *this;
 }
@@ -324,6 +331,10 @@ template<class T> Point3<T>::Point3(T _x, T _y, T _z) : x(_x), y(_y), z(_z)
 {
 }
 
+template<class T> Point3<T>::Point3(T* p) : x(p[0]), y(p[1]), z(p[2])
+{
+}
+
 
 //**** Point3 operators
 
@@ -514,12 +525,12 @@ template<class T> Vector4<T>& Vector4<T>::operator*=(T s)
     return *this;
 }
 
-template<class T> Vector4<T> Vector4<T>::operator-()
+template<class T> Vector4<T> Vector4<T>::operator-() const
 {
     return Vector4<T>(-x, -y, -z, -w);
 }
 
-template<class T> Vector4<T> Vector4<T>::operator+()
+template<class T> Vector4<T> Vector4<T>::operator+() const
 {
     return *this;
 }
@@ -760,6 +771,20 @@ template<class T> Matrix3<T> Matrix3<T>::zrotation(T angle)
 }
 
 
+template<class T> Matrix3<T> Matrix3<T>::scaling(const Vector3<T>& scale)
+{
+    return Matrix3<T>(Vector3<T>(scale.x, 0, 0),
+                      Vector3<T>(0, scale.y, 0),
+                      Vector3<T>(0, 0, scale.z));
+}
+
+
+template<class T> Matrix3<T> Matrix3<T>::scaling(T scale)
+{
+    return scaling(Vector3<T>(scale, scale, scale));
+}
+
+
 /***********************************************
  **
  **  Matrix4 methods
