@@ -49,4 +49,28 @@ void AddButtonDefaultStyle(HWND hWnd)
     SetWindowLong(hWnd, GWL_STYLE,
         ::GetWindowLong(hWnd, GWL_STYLE) | BS_DEFPUSHBUTTON);
 	InvalidateRect(hWnd, NULL, TRUE);
-}
\ No newline at end of file
+}
+
+const char* CurrentCP()
+{
+    static bool set = false;
+    static char cp[20] = "CP";
+    if (!set) {
+        GetLocaleInfo(GetThreadLocale(), LOCALE_IDEFAULTANSICODEPAGE, cp+2, 18);
+        set = true;
+    }
+    return cp;
+}
+
+string UTF8ToCurrentCP(const string& str)
+{
+    string localeStr;
+    LPWSTR wout = new wchar_t[str.length() + 1];
+    LPSTR out = new char[str.length() + 1];
+    int wlength = MultiByteToWideChar(CP_UTF8, 0, str.c_str(), -1, wout, str.length() + 1);
+    WideCharToMultiByte(CP_ACP, 0, wout, -1, out, str.length() + 1, NULL, NULL);
+    localeStr = out;
+    delete [] wout;
+    delete [] out;
+    return localeStr;
+}
